        PROGRAM POST
!  *****   This program is used to estimate the effects of land terraces and small federal reservoirs in the 
!  *****   Republican River Basin for each HUC 12. It takes the results from POTYLDR simulations for 
!  *****   conditions at each of 32 weather stations that have been assembled in the ASCII file, PSR,
!  *****   POTYLDR Simulation Results, along with an ASCII file of information for each HUC 12, HUCDAT,
!  *****   To calculate the best estimate of change in ET, runoff, and percolation in the HUC 12 along with
!  *****   the estimated downstream effect on runoff and change in transmission losses.  Three conditions
!  *****   are evaluated 1) terraces only, 2) reservoirs only, and 3) terraces and reservoirs combined.
!  *****   Output is put into an ASCII file, RESULTS -- a detailed account and 
!  *****   FINALRESULTS -- a summary for all HUC12s processed in a run.
!  *****    
      Implicit None
      INTEGER I,II,JJ,K,L,N,NN,I1,I2,I3,II1,II2,S,SO,TT,LU,VO,ST1,WS
      INTEGER STAID,STA,HUC12,SOIL,CC,DD,FF
      REAL SOILAREA,TOTAREA,TERRAREA,FLOWLENGTH,RESDRAINAREA,FATR
      REAL WEIGHT,TLF,VOLUME,V,LANDUSE,TERRTYPE,TERRACESPERMILEOFDRAINAGE 
      REAL AREA,AREASUM,SUMET,SUMRUNF,SUMPERC,X,SUMETHUC12,SUMRUNFHUC12
      REAL SUMPERCHUC12,ETA,RUNFA,PERCA,SUMAREAS,TOTALLANDBOVETERRACES
      REAL TTRANSLOSSFRAC,DSRUNFHUC12TO,TRANSLOSSTO,DA,NTA,RNTIN,RNTOUT
      REAL RNTPERC,RNTNET,PFULL,RTAREA,RWTIN,RWTOUT,RWTPERC,RWTNET 
      REAL TOTRNTIN,TOTRNTOUT,TOTRNTPERC,TOTRNTNET
      REAL TOTRWTIN,TOTRWTOUT,TOTRWTPERC,TOTRWTNET,DSRUNFHUC12RNT
      REAL DSRUNFHUC12RWT,TRANSLOSSRNT,TRANSLOSSRWT,SUMNETRWT,SUMPERCRWT
      REAL DSRUNFHUC12RCWT,TRANSLOSSRCWT,DTOTRUNFRNT 
      DIMENSION STA(3),WEIGHT(3),SOILAREA(3),LANDUSE(7),TERRTYPE(5)
      DIMENSION SUMET(3),SUMRUNF(3),SUMPERC(3)
      DIMENSION V(3,7,5), AREA(3,3,5,7)
! SOILAREA(X) = THE AMOUNT OF EACH OF THE THREE TYPES, X=1 IS TYPE 5, X=2 IS TYPE 7, AND X=3 IS TYPE 11
! SOIL = SOIL TYPE IN PSR FILE      
!  STA = APPLICABLE STATIONS FOR HUC, WEIGHT = RELATIVE WEIGHT FOR EACH OF THE 3 STATIONS
! SO = THE 3 SOIL TYPES USED IN ALL LOCATIONS - 5 = DEEP HEAVIER SILT LOAM, 7 = DEEP SILTY LOAM, 11 = SANDY
! V IS THE MATRIX THAT HOLDS THE 3 VALUES OF ET, RUNOFF, AND PERCOLATION FOR THE 5 TERRACE TYPES, 7 LANDUSES
! LANDUSE = 1 = CONTINUOUS ROWCROP, 2 = CONTINUOUS WINTER WHEAT, 3= WHEAT-CORN-FALLOW, 4 = WHEAT-FALLOW,
! 5 = HAY AND FORAGE, 6 = PASTURE/RANGE, 7 = IRRIGATED ROWCROPS
!TERRTYPE = 1 FOR NO TERRACES, 2 = LEVEL, CLOSED-END BROADBASE, 3 = LEVEL, CLOSED-END FLAT CHANNEL,
!4=LEVEL, OPEN-END BROADBASE, 5=LEVEL,OPEN-END, FLAT CHANNEL, 6 = GRADED, BROADBASE     
!      V(3,7,5)  3 = WATER AMOUNTS -- ET,RUNOFF,PERC; 7 = LAND USES; 5 =TERRACE TYPES, 
! 
!    ******************************************************************
      AREASUM=0.
      SUMETHUC12=0.
      SUMRUNFHUC12=0.
      SUMPERCHUC12=0.
      TOTRNTIN=0.      
      TOTRNTOUT=0. 
      TOTRNTPERC=0. 
      TOTRNTNET=0.
      TOTRWTIN=0.  
      TOTRWTOUT=0.
      TOTRWTPERC=0. 
      TOTRWTNET=0.
      TOTALLANDBOVETERRACES=0.
      SUMAREAS=0.0
      open(1,file='HUCDAT',status='old')  !HUC12 DATA FILE
      open(3,file='RESULTS',status='UNKNOWN') !RESULTS OUTPUT FILE
      open(4,file='FINALRESULTS',status='UNKNOWN') !FINAL RESULTS OUTPUT FILE      
      FATR=0.65  !PORTION OF TERRACED LAND ABOVE LOWEST TERRACE RIDGE AS A DECIMAL
      WRITE(4,5)
    5 FORMAT('FINAL RESULTS FOR EACH HUC12 IN AVERAGE AC-FT/YR AT ITS&
             & SUB-BASIN OUTLET',/,'VALUES UNDER EACH HEADING ARE CHANGE IN ET, STREAMFLOW,&
      & PERCOLATION AND TRANSMISSION LOSS, RESPECTIVELY',/,'HUC 12      &
      & FOR TERRACES ONLY           FOR RESERVOIRS ONLY     COMBINED&
	  & TERRACES & RESERVOIRS    FOR RESERVOIRS ONLY WITH TERRACES IN& 
	  & DRAINAGE AREA')  
! *****        
! ***************************************  BEGIN LOOP FOR EACH HUC12 ***************************      
      DO 2000 I=1,557   !START THE OVERALL PROCESS FOR EACH HUC12
! *****       	  
! *****       
! **************************  BEGIN  INDIVIDUAL HUC12 PROCESSING ***************************
! ***** 
!      open(2,file='PSR',status='old')
      OPEN(5,FILE='INTERMEDIATE',STATUS='UNKNOWN') ! HOLDS THE 9 PSR LINES SELECTED OUT FOR PROCESSING A HUC12
      READ(1,*) HUC12,TOTAREA,TERRAREA,FLOWLENGTH,RESDRAINAREA,&
      (SOILAREA(II),II=1,3),(LANDUSE(II),II=1,7),(TERRTYPE(II),II=1,5),&
      STA(1),WEIGHT(1),STA(2),WEIGHT(2),STA(3),WEIGHT(3),TLF
      WRITE(3,10) HUC12,TOTAREA,TERRAREA,FLOWLENGTH,RESDRAINAREA,&
      (SOILAREA(JJ),JJ=1,3),(TERRTYPE(JJ),JJ=1,5),(LANDUSE(JJ),JJ=1,7),&
      STA(1),WEIGHT(1),STA(2),WEIGHT(2),STA(3),WEIGHT(3),TLF
   10 FORMAT('DUMP OF HUC12 INFO',/,I6,4F10.2,3F6.2,5F5.1,7F5.1,&
        &I7,F6.3,I7,F6.3,I7,F6.3,F5.2)
!  *****
!  ***** SEARCH THROUGH PSR FILE FROM POTYLDR TO FIND THE THREE APPLICABLE STATIONS FOR THE HUC12
		FF=1
      DO 190 CC=1,100
      open(2,file='PSR',status='old')
	  READ(2,*) STAID,SOIL,V,RNTIN,RNTOUT,RNTPERC,RNTNET,&
	    RWTIN,RWTOUT,RWTPERC,RWTNET,TERRACESPERMILEOFDRAINAGE 
         IF(STAID.NE.STA(FF)) GOTO 190
	  WRITE(5,111) STAID,SOIL,V,RNTIN,&
		  RNTOUT,RNTPERC,RNTNET,RWTIN,RWTOUT,RWTPERC,RWTNET,&
                  TERRACESPERMILEOFDRAINAGE   		  
	  DO 150 DD=1,2
	  READ(2,*) STAID,SOIL,V,RNTIN,RNTOUT,RNTPERC,RNTNET,&
	    RWTIN,RWTOUT,RWTPERC,RWTNET,TERRACESPERMILEOFDRAINAGE 	
	  WRITE(5,111) STAID,SOIL,V,RNTIN,RNTOUT,RNTPERC,RNTNET,RWTIN,&
	  RWTOUT,RWTPERC,RWTNET,TERRACESPERMILEOFDRAINAGE 
  111 FORMAT(I7, I3,105F9.3,8F9.3,F7.3)
  150 CONTINUE
		CLOSE(2,STATUS='KEEP')
        FF=FF+1
			IF(FF.GT.3) GOTO 195
  190 CONTINUE
  195 CLOSE (5,STATUS='KEEP')
!  ***** END THE SEARCH PROCESS AND CONTINUE TO PROCESS RESULTS FOR THE INDIVIDUAL HUC12 
 	OPEN(5,FILE='INTERMEDIATE',STATUS='UNKNOWN')
	TOTALLANDBOVETERRACES=TERRAREA*FATR/640.
      WRITE(3,42) TOTALLANDBOVETERRACES
   42 FORMAT('TOTAL AREA IN HUC12 ABOVE TERRACES'&
      &/,F6.3,/,'ST,SO,TT,LU SQUARE MILES FOR EACH STATION-SOIL-&
       &LANDUSE-TERRACE TYPE COMBINATION')  
! *****      Calculate the amount of each soil type-landuse-terrace type combination ABOVE A TERRACE RIDGE for each of the 3 stations for the HUC12.
	DO 100 S=1,3 ! S=STATION COUNT
	  DO 090 SO=1,3 ! SO=SOIL TYPE
	    DO 080  TT=1,5 !TT=TERRACE TYPE
	      DO 070 LU=1,7 ! LU=LAND USE
        AREA(S,SO,TT,LU) = WEIGHT(S)*SOILAREA(SO)/100.&
          *TERRTYPE(TT)/100.*LANDUSE(LU)/100.*TOTALLANDBOVETERRACES
	WRITE(3,15) S,SO,TT,LU,AREA(S,SO,TT,LU),WEIGHT(S),SOILAREA(SO),&
	     LANDUSE(LU),TERRTYPE(TT)
	AREASUM = AREASUM+AREA(S,SO,TT,LU)
     15 FORMAT (I2,3I3,F8.5,F6.3,3F5.1)	
     70 CONTINUE
     80 CONTINUE
     90 CONTINUE
    100 CONTINUE 
        WRITE (3,12) AREASUM
     12 FORMAT('TOTAL LAND IN HUC12 ABOVE A TERRACE RIDGE&
       & IN SQUARE MILES =',F7.3,/)
! *****   END OF CALCULATIONS FOR AMOUNT OF AREA FOR EACH soil type-landuse-terrace type combination for each of the 3 stations for the HUC12.	 
        READ(5,*) STAID,SOIL,V,RNTIN,RNTOUT,RNTPERC,RNTNET,&
	    RWTIN,RWTOUT,RWTPERC,RWTNET,TERRACESPERMILEOFDRAINAGE  
!LOOP FOR THE THREE WEATHER STATIONS FOR HUC12 TO CALCULATE THE AMOUNT OF 
!EFFECTS FOR TERRACES ONLY AND RESERVOIRS ONLY.
         DO 1500 WS=1,3
! LOOP FOR THE THREE SOIL TYPES AT WEATHER STATION ST1 FOR THE HUC12 TO 
!CALCULATE THE AMOUNT OF EFFECTS FOR TERRACES ONLY AND RESERVOIRS ONLY.
        DO 1000 ST1=1,3     
	IF(ST1.EQ.1) WRITE(3,20)HUC12,STA(WS)
	IF(ST1.EQ.2) WRITE(3,21)HUC12,STA(WS)
	IF(ST1.EQ.3) WRITE(3,22)HUC12,STA(WS) 
 !  ********************************************************************************
!  ******  COLLECT VALUES FOR RESERVOIRS ONLY AMOUNTS HERE AS DATA IS READ IN
!  ******  THE TOTAL VALUE WILL BE KEPT FOR ADDITIONAL PROCESSING TO CALCULATE
!  ******  THE EFFECT OF RESERVOIRS ONLY ON STREAMFLOW AND TRANSMISSION LOSSES.
!  ******
        TOTRNTIN=TOTRNTIN+RNTIN*RESDRAINAREA/640.&
           *WEIGHT(WS)*SOILAREA(ST1)/100.	      
        TOTRNTOUT=TOTRNTOUT+RNTOUT*RESDRAINAREA/640.&
           *WEIGHT(WS)*SOILAREA(ST1)/100.
        TOTRNTPERC=TOTRNTPERC+RNTPERC*RESDRAINAREA/640.&
           *WEIGHT(WS)*SOILAREA(ST1)/100.
        TOTRNTNET=TOTRNTNET+RNTNET*RESDRAINAREA/640.&
           *WEIGHT(WS)*SOILAREA(ST1)/100.		   
!  **********************************************************************************
!  ******  COLLECT RESERVOIRS WITH TERRACES AMOUNTS HERE AS DATA IS READ IN
!  ******  THE TOTAL VALUE WILL BE KEPT FOR ADDITIONAL PROCESSING TO CALCULATE
!  ******  THE EFFECT OF THE COMBINATION OF TERRACES AND RESERVOIRS  ON
!  ******  STREAMFLOW AND TRANSMISSION LOSSES..
!  ******
        TOTRWTIN=TOTRWTIN+RWTIN*RESDRAINAREA/640.&
           *WEIGHT(WS)*SOILAREA(ST1)/100.	      
        TOTRWTOUT=TOTRWTOUT+RWTOUT*RESDRAINAREA/640.&
           *WEIGHT(WS)*SOILAREA(ST1)/100.
        TOTRWTPERC=TOTRWTPERC+RWTPERC*RESDRAINAREA/640.&
           *WEIGHT(WS)*SOILAREA(ST1)/100.
        TOTRWTNET=TOTRWTNET+RWTNET*RESDRAINAREA/640.&
           *WEIGHT(WS)*SOILAREA(ST1)/100.
!  *********************************************************************************	   
    20 FORMAT('RESULTS FOR HUC12',I7,' FOR STATION = ',I6,&
          &' ONLY FOR SOIL 5 PORTION ONLY')
    21 FORMAT('RESULTS FOR HUC12',I7,' FOR STATION = ',I6,&
        &'  ONLY FOR SOIL 7 PORTION ONLY')
    22 FORMAT('RESULTS FOR HUC12',I7,' FOR STATION = ',I6,&
        &' ONLY FOR SOIL 11 PORTION ONLY')
       WRITE(3,23) 
    23 FORMAT('ST,SO,TT,LU, AREA    ET    RUNOFF  &
	  &PERCOLATION, TOTAL AC-FT')       
       DO 300 TT=1,5
       DO 290 LU=1,7
    999 FORMAT(I2,3I3,F8.5,6F7.2)
        ETA=AREA(WS,ST1,TT,LU)*V(1,LU,TT)
       SUMET(ST1)=SUMET(ST1)+ETA
        RUNFA=AREA(WS,ST1,TT,LU)*V(2,LU,TT)
       SUMRUNF(ST1)=SUMRUNF(ST1)+RUNFA
        PERCA=AREA(WS,ST1,TT,LU)*V(3,LU,TT)
       SUMPERC(ST1)=SUMPERC(ST1)+PERCA
       SUMAREAS=SUMAREAS+AREA(WS,ST1,TT,LU)
       WRITE(3,999) WS,ST1,TT,LU,AREA(WS,ST1,TT,LU),V(1,LU,TT),&
            V(2,LU,TT),V(3,LU,TT),ETA,RUNFA,PERCA
   290 CONTINUE  
   300 CONTINUE  
       WRITE(3,310) SUMAREAS,SUMET(ST1),SUMRUNF(ST1),SUMPERC(ST1)
        SUMETHUC12=SUMETHUC12+SUMET(ST1)
	    SUMRUNFHUC12=SUMRUNFHUC12+SUMRUNF(ST1)
	    SUMPERCHUC12=SUMPERCHUC12+SUMPERC(ST1)
        SUMET(ST1)=0.0
	    SUMRUNF(ST1)=0.0
	    SUMPERC(ST1)=0.0
  310  FORMAT(11X,F6.3,22X,3F8.2)
  1000 CONTINUE
  1500 CONTINUE
      WRITE(3,1510) HUC12  
  1510 FORMAT(/,'FINAL RESULTS IN AC-FT/YR FOR HUC12 =',I7,&
       &' CHANGE IN',/,'  ET STREAMFLOW PERCOLATION TRANSMISSION LOSSES')
      WRITE(3,1511) SUMETHUC12,SUMRUNFHUC12,SUMPERCHUC12
  1511 FORMAT(F5.1,2F9.1,'  AT EDGE OF TERRACED FIELD')      
!  ****** CALCULATE EFFECTS OF TERRACES ONLY HERE ON STREAMFLOW AND TRANSMISSION LOSSES
      TTRANSLOSSFRAC=1-(1-TLF/100)**FLOWLENGTH
      DSRUNFHUC12TO=SUMRUNFHUC12*(1-TTRANSLOSSFRAC)
      TRANSLOSSTO=SUMRUNFHUC12-DSRUNFHUC12TO
      WRITE(3,1515) SUMETHUC12,DSRUNFHUC12TO,SUMPERCHUC12,TRANSLOSSTO
 1515 FORMAT(F5.0,F8.0,F10.0,F14.0,'  RESULTS FOR TERRACES ONLY')
!  ****** CALCULATE EFFECTS OF RESERVOIRS ONLY WITH NO TERRACES IN DRAINAGE AREA HERE ON STREAMFLOW AND TRANSMISSION LOSSES
            DTOTRUNFRNT=TOTRNTOUT-TOTRNTIN
      WRITE(3,1517) TOTRNTNET,TOTRNTOUT,TOTRNTIN,DTOTRUNFRNT,TOTRNTPERC
 1517 FORMAT(F5.1,4F9.1,'  AT RESERVOIR LOCATION WITH NO TERRACES')
      DSRUNFHUC12RNT=(TOTRNTOUT-TOTRNTIN)*(1-TTRANSLOSSFRAC)
      TRANSLOSSRNT=(TOTRNTOUT-TOTRNTIN)-DSRUNFHUC12RNT
      WRITE(3,1516) TOTRNTNET,DSRUNFHUC12RNT,TOTRNTPERC,TRANSLOSSRNT
 1516 FORMAT(F5.0,F8.0,F10.0,F14.0,&
        &'  RESULTS FOR RESERVOIRS ONLY WITH NO TERRACES')
!  ****** CALCULATE EFFECTS OF RESERVOIRS ONLY WITH TERRACES IN DRAINAGE AREA HERE ON STREAMFLOW AND TRANSMISSION LOSSES	  
      DSRUNFHUC12RWT=(TOTRWTOUT-TOTRWTIN)*(1-TTRANSLOSSFRAC)
      TRANSLOSSRWT=(TOTRWTOUT-TOTRWTIN)-DSRUNFHUC12RWT
      WRITE(3,1518) TOTRWTNET,(TOTRWTOUT-TOTRWTIN),TOTRWTPERC
 1518 FORMAT(F5.1,2F9.1,'  AT RESERVOIR LOCATION WITH TERRACES&
      & IN DRAINAGE AREA') 
      WRITE(3,1519) TOTRWTNET,DSRUNFHUC12RWT,TOTRWTPERC,TRANSLOSSRWT
 1519 FORMAT(F5.0,F8.0,F10.0,F14.0,&
      '  RESULTS FOR RESERVOIRS ONLY WITH TERRACES IN DRAINAGE AREA')    
!  ****** CALCULATE EFFECTS OF RESERVOIRS  AND TERRACES COMBINED HERE ON ET, PERCOLATION, STREAMFLOW AND TRANSMISSION LOSSES 
!              THE ET IS THE SUM FOR RESERVOIRS WITH TERRACES IN THEIR DRAINAGE AREA + THE ET FROM ALL TERRACES SINCE ALL TERRACES HAVE ET EFFECTS.
!              THE PERCOLATION IS THE SUM FOR RESERVIORS WITH TERRACES IN THE DRAINAGE AREA + THE PERCOLATION FROM ALL THE TERRACES.
!              THE EFFECT ON STREAMFLOW FOR THE COMBINED TERRACES AND RESERVOIRS MUST ACCOUNT FOR THE TERRACES THAT ARE IN THE DRAINAGE AREAS OF
!              OF THE RESERVOIRS.  ONLY THAT PORTION OF THE AREA ABOVE TERRACES THAT ARE NOT ABOVE RESERVOIRS CAN BE COUNTED.  SO, THE TOTAL EFFECTS
!              IS THE TOTAL OF (RUNOFF REDUCTION BY ALL THE TERRACES NOT ABOVE RESERVOIRS + THE REDUCTION IN RUNOFF BY THE RESERVOIRS WITH 
!              TERRACES IN DRAINAGE AREA) TIMES (1-TLF)**STREAMLENGTH.  THE REDUCTION IN TRANSMISSION LOSSES IS THE TOTAL UPSTREAM RUNOFF
!              REDUCTION MINUS THE STREAMFLOW REDUCTION.
      SUMNETRWT=SUMETHUC12+TOTRWTNET
      SUMPERCRWT=SUMPERCHUC12+TOTRWTPERC
!	SUMRUNFHUC12=SUMRUNFHUC12*(SUMAREAS-TERRACESPERMILEOFDRAINAGE&
!	*RESDRAINAREA/640.)/SUMAREAS
      DSRUNFHUC12RCWT=(SUMRUNFHUC12+(TOTRWTOUT-TOTRWTIN))&
           *(1-TTRANSLOSSFRAC)
      TRANSLOSSRCWT=-(DSRUNFHUC12RCWT-(SUMRUNFHUC12+&
           (TOTRWTOUT-TOTRWTIN)))
      WRITE(3,1600) SUMNETRWT,DSRUNFHUC12RCWT,SUMPERCRWT,TRANSLOSSRCWT
 1600 FORMAT(F5.0,F8.0,F10.0,F14.0,&
      &'  COMBINED RESULTS FOR TERRACES AND RESERVOIRS WITH TERRACES',/)     
!  ***** WRITE RESULTS FOR EACH HUC12 TO FINALRESULTS AS A 1-LINE STRING
      WRITE(4,1800)HUC12,SUMETHUC12,DSRUNFHUC12TO,SUMPERCHUC12,TRANSLOSSTO,&
	    TOTRNTNET,DSRUNFHUC12RNT,TOTRNTPERC,TRANSLOSSRNT,&
            SUMNETRWT,DSRUNFHUC12RCWT,SUMPERCRWT,TRANSLOSSRCWT,&
	    TOTRWTNET,DSRUNFHUC12RWT,TOTRWTPERC,TRANSLOSSRWT 
 1800 FORMAT(I6,4F7.1,X,4F7.1,X,4F7.1,8X,4F7.1)	
      AREASUM=0.
	  SUMETHUC12=0.
	  SUMRUNFHUC12=0.
	  SUMPERCHUC12=0.
      TOTRNTIN=0.      
      TOTRNTOUT=0. 
      TOTRNTPERC=0. 
      TOTRNTNET=0.
	  TOTRWTIN=0.  
      TOTRWTOUT=0.
      TOTRWTPERC=0. 
      TOTRWTNET=0.
	  TOTALLANDBOVETERRACES=0.
      SUMAREAS=0.0
      CLOSE (5,STATUS='KEEP')
      CLOSE (2,STATUS='KEEP')	       
 2000 CONTINUE  
      CLOSE (1,STATUS='KEEP')
      CLOSE (2,STATUS='KEEP')
      CLOSE (3,STATUS='KEEP')     
      CLOSE (4,STATUS='KEEP')
      CLOSE (5,STATUS='KEEP')      
 3000 STOP
      END PROGRAM POST
