	PROGRAM POTYLDR2
!  *****	(Named V.F90 for a shortcut Identifier)
!  *****   This version, 2.0, was developed for the Republican River Basin Study of the Effects of Land Terracing and
!  *****   Small Reservoirs on Streamflow and Ground-water Recharge. 
!  *****   Major modifications include -- use of daily Grass-reference ET values, ETo, developed by Derrel Martin,
!  *****   Use of weekly crop-water use coefficients by geopgraphical region based upon climatic conditions at 
!  *****   a particular location, use of monthly runoff-curve numbers (RCN) use of monthly 
!  *****   residue cover factors to reduce evaporation losses during non-growing periods, use of a factor to  
!  *****   to simulate surface runoff reduction by terracing that reduces the RCN by a constant factor for the HRU, 
!  *****   use of a depth for the lower zone of the soil profile instead of an assigned depth, varying the daily seepage
!  *****   rate from small reservoirs as a function of relative depth in the reservoir -- a minimum seepage rate at
!  *****   zero depth and a maximum seepage rate at full are specified by the user, and a 6-year land-use rotation
!  *****   for each HRU.  The RCN, residue factor, and crop-water use factors can all be changed by a factor if
!  *****   the default values are judged to be less than satisfactory for a location.
!  *****   Irrigation management for the effect of applied water on potential runoff has been incorporated by
!  *****   adding half of the irrigation amount to rainfall before calculating interception losses and runoff for
!  *****   the day.  Interception has been changed to 0.07 inches maximum from 0.10 inches.  
!  *****   An output file for the first HRU has been added that provides the input to simulate the operation of
!  *****   a terrace as a pond to predict the overflow and seepage of stored water into the storage area of a 
!  *****   terrace at various levels from the bottom by the program, TERRACEPOND.  Output from TERRACEPOND
!  *****   is passed to TERRACECHANNEL to simulate the water budget on each of the levels in the terrace
!  *****   storage area to estimate the amount of percolation below the rooting zone of terrace storage area.
!  *****   Outputs of various ASCII files have been modified so that more information from the runs can be
!  *****   further processed in spreadsheets or other programs to provide results in formats more suitable for
!  *****   a particular use such as percent full for the small reservoir with time.
!  *****   The option in the original POTYLDR to do post-processing for a small watershed has been removed
!  *****   from POTYLDR 2.0 at this time to simplify this version for its specific purpose.  Note:  A number of
! *****    variables that were part of the post-processing parts of POTYLDR are still in this code.  Output files from
! *****    POTYLDR are still made so that particular aspects of the water-budget results are available for users.
! *****
      Implicit None
      INTEGER CROP,DGSB,DGSBP,DGSE,DGSEP,FROZE,OUTPUT,MONTHT
      INTEGER POND,PREVYR,ROTATE,SOIL,JJ,KL,MP,LU,LY,ZZ
      INTEGER YEAR,YEARS,YEND,YSTART,KK,MM,N3,N2,N1,INUM,KM
      INTEGER SMDI,PERS,SPER,COUNT,NTMX,NTMN,MO,NDIM,IPD,WEEK
      INTEGER L6,IPLOT,KI,KT,III,MT,NDAYS,ND,IPLOTS,NPLOTS,IK
      INTEGER IDAY,IMON,IYR,I100TH,ISEC,IMIN,IHR,I,IR,IRGPLT,LYEAR,J
      INTEGER NPD,K,MGSB,MGSE,IJ,KJ,II,NY,IROT,NM,MONTH,ISOIL
      INTEGER MGSEP,MGSBP,NPLOT,NODSCH,I3,LL,L5,INUM1,ICROP,INCROP
      INTEGER IDYEND,IMOEND,IDYBEG,IMOBEG,NYDSCH,NDOY,L9
      REAL IACCT,INPOT,INTERC,INRCN1,INRCN2,INRCN3,KCROP,KROPKO,MD,LAKEP
      REAL LAKEVT,AL,T,CONSTANT,IACCTT,MELT,LAVGPNDFULL
      REAL LAKEVP,LKEVPT,MMAT,MMMAXT,MMMINT,MUL,NIA,NDPERC,NRNOF,AVGT
      REAL DAYPE,PDSEEP,PDOUTF,PDOUTE,PONDSP,EVAP,APPREC,ADYD
      REAL RCNADJ,RESADJ,KADJ,LZDEPTH,X,PETD,SEEPRATE,MAXSEPRT,TCNFACTOR
      REAL AVGPNDFULL,TCNF,SEEPAGE,PETX,S1,S2
      REAL RANGE,AVGMD,PRECPA,PEINA,EVAPA,EXFILA,DISCRGA,PETAVG,RES
      REAL AVABDCMDSCRGM,B2,SEVAP,DASEEP,PRCPVL,DSCHRG,PCNTRL,PNDSEP
      REAL SYLDNT,SYLDAF,PYLDAF,TTYLD,WTLF,AVGSUF,AVGPER,C,ASTAT
      REAL VOLMX1,VCB,VCD,VC1,DIM,CNTR,DSNOW,DRY,DAYLD,APREC,PRCPA
      REAL DSCRGA,AVANDC,PNDOUT,PNDEV,PRC,TLF,PSEEP,PNDYLD,ETrPM
      REAL ZWIND,ZRHD,ZRA,ZPSUNS,ZMAXT,ZMINT,ZMN,ZND,TAVGM,STRVOL
      REAL ZNM,PET,GAMMA,STRNOF,ZSMUZ,ZPWPUZ,ZAVGFCU,RCN1,RCN2,CNADJ
      REAL RCN3,ZSM,SNOWPACK,PRECIP,SNOVAP,RAIN,RNOF
      REAL SWTCH,AMTIRR,UZEVAP,SMMAXU,PERCL,V,HAPRX,VC,DV,DVHD,VCC,DSCRG
      REAL AVGYLD,TAREA,RCROP,E,BRUNTB,BRUNTA,S,W,HMAX,DSEPRT,VOLMAX
      REAL PSAREA,A5,A4,A3,A2,A1,PLAREA,TERT,MAXVOL,VOLCHG,DELTA,ZAVFCU
      REAL DVDH,DVAL,PETACT,PLU,PRECAC,PDACCT,CTR,SMACCT,RUNACC,SMMAXL
      REAL PDT,EPRIM,CONTRL,AVAILU,AVAILL,AETUZ,AETLZ,AET,DPREC,DA
      REAL CTPDAY,H,EXFILT,EXCESS,EVAPT,EVAPLK,DSCVOL,PEINT,PEAK,PDVOL
      REAL PACKPY,TPAREA,PRCPT,PONVOL,PETTAC,PERC,WET,WATER,TPERC,PRCT
      REAL TPYLDA,TSYLDA,TTSUYL,TBSUYL,TPRYLD,TSUYLD,TIRRIG,AIRRIG,PACK
      REAL PXCLU,PXCLUM,SYLDLU,PRYLD,PEACCT,PCROP,PWPUZ,PWPLZ,PSUNS,PREC
      REAL PNDOT,PRP,RHD,RCNIII,RCNII,RCNI,RA,SMLZ,SMGLZ,SM,SMUZ,SMATU
      REAL SMPD,TOTLKE,TMIN,TMAX,TAVG,WIND,U,DPERC,AETU,AETL,ACHSOM,AAETRS
      REAL AREA,AINTER,CTP,ROPAVLFCU,AVLFCL,CTRDAY,CTPR,EO,DSRNFF,DSPERC
      REAL FLRCN2,FLRCN1,FCU,FCL,FREQ,FLRCN3,TIRRG,PSCH,PERCLU,SMGWZ
      REAL TPREC,SMSATU,AVLFCU,ARATE,IAET,TERRACEDAREA,PONDPERCENTFULL
      REAL AVGAAETRS,AVGDSRNFF,AVGDSPERC,DAO,PEINAO,DSCRGAO,NETO,EXFILAO
      DIMENSION AAETRS(24), ACHSOM(24), AETL(24), AETU(24),MONTHT(13)
      DIMENSION AINTER(24), AREA(24), ASTAT(25),IPD(24)
      DIMENSION AVLFCL(12), AVLFCU(12), C(12), CTP(25), CROP(24,8)
      DIMENSION CTPR(25), CTRDAY(04), DGSBP(24)
      DIMENSION DGSEP(24), DSPERC(24), DSRNFF(24), EO(24)
      DIMENSION FCL(12), FCU(12), FLRCN1(24), FLRCN2(24)
      DIMENSION FLRCN3(24), FREQ(25), IACCTT(24), ICROP(24),LU(24,6)
      DIMENSION INCROP(24), INRCN1(24), INRCN2(24), INRCN3(24)
      DIMENSION IMOBEG(24), IDYBEG(24), IMOEND(24),IDYEND(24)
      DIMENSION PSCH(24), ARATE(24), AIRRIG(24),TIRRG(24)
      DIMENSION ISOIL(24), PERCLU(24), PXCLU(24),PACK(24)
      DIMENSION PRYLD(24), SYLDLU(24), PXCLUM(24,12) 
      DIMENSION MGSBP(24), MGSEP(24), MMAT(12), MMMAXT(12), MMMINT(12)
      DIMENSION MO(12), NDIM(12), NDPERC(24), NIA(24)
      DIMENSION NPLOT(24), NRNOF(24), PCROP(24), PEACCT(24)
      DIMENSION POND(24),PREC(31), PSUNS(12), PWPLZ(12), PWPUZ(12)
      DIMENSION PRP(12), LAKEP(12), PNDOT(12)
      DIMENSION RCNII(10,12),KCROP(10,53), RES(10,12)
      DIMENSION ROTATE(24), SM(24), SMGWZ(24), SMLZ(24)
      DIMENSION SMPD(24), SMSATU(12), SMUZ(24), T(24),ETrPM(31) 
      DIMENSION TCNF(24), TMAX(31), TMIN(31), TOTLKE(12)
      DIMENSION U(12), WIND(12), PLU(24), PETACT(13), DVAL(24,6)
      DIMENSION CTR(25,4), PDACCT(13,9), PRECAC(25,4)
      DIMENSION RUNACC(25,25), SMACCT(13,9,24), krop(10), NTERR(4)
      INTEGER*4 PINDX, TINDX, ETINDX, PSTIND, TSTIND, ETSTIND
      CHARACTER*36 FILE2,FILE3,FILE4,FILE5,FILE6,FILE7
      CHARACTER*3 FILE21
      CHARACTER*10 FILE19
      CHARACTER*36 MASTER,FILE8,FILE9
      CHARACTER*16 krop
      CHARACTER*20 NTERR
      CHARACTER*34 HIST,FIXED,STRNG
      CHARACTER*80 location 
      CHARACTER*4 plit
      CHARACTER*4 PTER
      CHARACTER*2 NO
      CHARACTER*3 BLNK
      CHARACTER*3 NOT
      CHARACTER (LEN=12) :: MS='mnthsurf.out'
      CHARACTER (LEN=12) :: AS='annlsurf.out'
      CHARACTER (LEN=12) :: MPE='mnthperc.out'
      CHARACTER (LEN=12) :: AP='annlperc.out'
      CHARACTER (LEN=12) :: AIRR='annlirrg.out'
      CHARACTER (LEN=12) :: MIRR='mnthirrg.out'
      CHARACTER (LEN=11) :: MYLD='mnthyld.out'
      CHARACTER (LEN=11) :: AYLD='annlyld.out'
      CHARACTER (LEN=12) :: PMB='mnthpond.out'
      CHARACTER (LEN=12) :: PAB='annlpond.out'
      DATA NOT/'NOT'/
      DATA blnk/'  '/
      DATA no/'NO'/
      DATA krop/'WHEAT PLANT','WHEAT HARVEST','DRYLAND CORN','SORGHUM',&
            'SOYBEANS','HAY/FORAGE','GRASS/PASTURE','FALLOW',&
	    'CONT. WHEAT','IRRIGATED CORN'/
      DATA MONTHT/1,2,3,4,5,6,7,8,9,10,11,12,99/
      DATA HIST/'FOR HISTORICAL HRUS WITH TIME'/
      DATA FIXED/'FOR HRUS FIXED WITH TIME'/
      DATA ASTAT/0.0,0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9,1.0,&
		    1.1,1.2,1.3,1.4,1.5,1.6,1.7,1.8,1.9,2.0,3.0,4.0,5.0,10./
      DATA AVLFCL/1.8,1.5,2.1,2.1,2.3,2.0,1.8,2.1,1.6,0.8,1.2,0.8/
      DATA AVLFCU/2.6,1.5,2.5,2.4,2.5,2.6,2.4,2.4,2.4,2.2,1.5,1.0/
      DATA C/0.2,0.2,0.177,0.177,0.177,0.177,0.159,0.159,0.138,0.138,0.1&
                    34,0.131/
      DATA FCL/5.2,4.8,4.9,4.7,4.7,4.4,3.6,4.1,2.6,1.8,2.2,1.4/
      DATA FCU/4.6,4.4,4.5,4.6,4.5,4.3,4.0,4.0,3.8,3.5,2.3,1.7/
      DATA FREQ/0.0,0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9,1.0,1.1,1.2,1.3,&
                    1.4,1.5,1.6,1.7,1.8,1.9,2.0,3.0,4.0,5.0,10.0/
      DATA NDIM/31,28,31,30,31,30,31,31,30,31,30,31/
      DATA PWPLZ/3.4,3.3,2.8,2.6,2.4,2.4,1.8,2.0,1.0,1.0,1.0,0.6/
      DATA PWPUZ/2.0,2.9,2.0,2.2,2.0,1.7,1.6,1.6,1.4,1.3,0.8,0.7/
      DATA SMSATU/5.8,6.2,5.7,5.7,5.7,5.5,5.4,5.4,5.3,5.2,4.8,4.8/
      DATA U/0.47,0.47,0.39,0.39,0.39,0.39,0.35,0.35,0.31,0.31,0.28,0.24/
      DATA CONSTANT/0.08/
!   *****   Runoff curve number AMC II by crop by month for 10 land uses in columns and months in rows
      DATA RCNII/73,76,73,73,73,70,68,73,75,71,&
		 74,76,73,73,73,71,69,74,75,71,&
		 75,76,74,74,74,72,70,75,75,72,&
		 76,74,75,75,75,72,70,76,74,72,&
		 77,73,76,76,76,71,69,77,73,73,&
		 78,70,75,77,76,70,68,78,70,73,&
		 78,70,74,76,76,70,68,78,70,72,&
		 78,70,73,74,75,70,68,78,72,72,&
		 79,70,73,74,76,70,68,79,73,71,&
		 79,71,72,73,74,70,68,79,74,71,&
		 76,72,72,73,74,70,68,79,74,71,&
		 76,73,73,73,74,70,68,79,74,71/ 
!  *****  Monthly residue factor by land use by month for 10 land uses in columns and months in rows
       DATA RES/0.40,0.30,0.30,0.30,0.30,0.40,0.40,0.30,0.30,0.50,&
		0.40,0.30,0.30,0.30,0.30,0.40,0.40,0.30,0.30,0.50,&
		0.40,0.30,0.20,0.20,0.20,0.40,0.40,0.30,0.30,0.50,&
		0.30,0.30,0.20,0.20,0.20,0.40,0.40,0.30,0.30,0.30,&
		0.30,0.30,0.20,0.20,0.20,0.40,0.40,0.20,0.30,0.30,&
		0.30,0.30,0.20,0.20,0.20,0.40,0.40,0.20,0.30,0.30,&
		0.20,0.50,0.20,0.20,0.20,0.40,0.40,0.20,0.50,0.30,&
		0.20,0.50,0.20,0.20,0.20,0.40,0.40,0.20,0.50,0.30,&
		0.20,0.50,0.30,0.30,0.30,0.40,0.40,0.20,0.40,0.40,&
		0.20,0.50,0.50,0.50,0.50,0.40,0.40,0.20,0.30,0.50,&
		0.30,0.40,0.50,0.50,0.50,0.40,0.40,0.20,0.30,0.50,&
		0.30,0.40,0.40,0.40,0.40,0.40,0.40,0.20,0.30,0.50/
      DATA CONTRL,EPRIM,PDT,SMMAXL/1.0,0.5,37.5,2.2/
      DATA COUNT,FROZE,NODSCH,NYDSCH,SOIL/5*0/
      DATA CROP/192*0/
      DATA IPD/24*0/
      DATA AET,AETLZ,AETUZ,AVAILL,AVAILU,CTP/30*0.0/
      DATA CTPDAY,CTPR,CTR,CTRDAY,DA,DPERC/132*0.0/
      DATA DSCVOL,EVAPLK,EVAPT,EXCESS,EXFILT,H/6*0.0/
      DATA PACKPY,PDVOL,PEAK,PEINT,SEEPRATE/5*0.0/
      DATA PACK/24*0.0/
      DATA PERC,PETACT,PETTAC,PONVOL,PRCPT,SM,TPAREA/42*0.0/
      DATA WATER,WET/2*0.0/
      DATA TPREC/0.0/
      DATA PSCH,ARATE,AIRRIG,TIRRG/96*0.0/
      DATA A1,A2,A3,A4,A5,VOLMAX,PSAREA/7*0.0/
      DATA TSUYLD,TPRYLD,TBSUYL,TTSUYL,TSYLDA,TPYLDA,PRCT,LAKEVT/8*0.0/
!    ******************************************************************
      write(*,2)
    2 format(' Enter the name of the master file for this run.',/'    Th&
     &is file must reside on the disk. ')
      open(1,file=' ',status='old')
!     *****   READ LOCATION INFO, HRU AREAS AND RESERVOIR PARAMETERS      
      read (1,*) MASTER,LOCATION !Input file and description of what's simulated in this run.
      read (1,*) file2, file3, file4, file5, file6, file8, file19
      open(2,file=FILE2,status='old') !Precip file      Stationnamepcp.dat
      open(3,file=FILE3,status='old') !Temperature file  Stationnametmp.dat
      open(15,file=FILE4,status='old') !Grass Reference ET file StationnmeEToPM.dat  
      open(5,file=FILE5,status='UNKNOWN') !Output file of Results for the Run
      open(20,file=FILE6,status='UNKNOWN') !Weekly Crop Coefficients file, WUCxxxxx, where xxxxx = west, middle or east
      open(19,file=FILE19,status='UNKNOWN') !Average Annual Output file for HRU results in acre-feet/square mile
      FILE21='ONE'
      if(LEN_TRIM(FILE19).EQ.10) FILE21='TWO'
      open(21,file=FILE21,status='UNKNOWN') !Average Annual Output file for HRU results in acre-feet/square mile for further processing
      open(31,file='HRU1',status='UNKNOWN')  !Daily Output file from HRU1 for Input to TERRACEPOND
      open(32,file='HRU2',status='UNKNOWN')  !Daily Output file from HRU2 for Input to TERRACEPOND
      open(33,file='HRU3',status='UNKNOWN')  !Daily Output file from HRU3 for Input to TERRACEPOND
      open(34,file='HRU4',status='UNKNOWN')  !Daily Output file from HRU4 for Input to TERRACEPOND
      open(35,file='HRU5',status='UNKNOWN')  !Daily Output file from HRU5 for Input to TERRACEPOND
      open(36,file='HRU6',status='UNKNOWN')  !Daily Output file from HRU6 for Input to TERRACEPOND
      open(37,file='HRU7',status='UNKNOWN')  !Daily Output file from HRU7 for Input to TERRACEPOND
      open(38,file='HRU8',status='UNKNOWN')  !Daily Output file from HRU8 for Input to TERRACEPOND      
      open(39,file='HRU9',status='UNKNOWN')  !Daily Output file from HRU9 for Input to TERRACEPOND          
      open(40,file='HRU10',status='UNKNOWN')  !Daily Output file from HRU10 for Input to TERRACEPOND  
!    *****
!    *****   READ CLIMATOLOGICAL INFO, HRU AREAS AND RESERVOIR PARAMETERS
      read (1,*)DSEPRT,MAXSEPRT,HMAX,AL,W,S,OUTPUT
      read (1,*)pindx,tindx,etindx,ystart,yend,nplots,iplots,&
               rcnadj,resadj,kadj,LZDEPTH
! READ IN WEEKLY CROP COEFFICIENTS FROM FILE
      DO IK=1,53
      READ (20,*) (KCROP(KM,IK),KM=1,10)  !file WUCxxxx where xxxx=east, middle or west for unadjusted values.
        END DO
      CLOSE (20,STATUS='KEEP')
      CALL GETDAT (IYR,IMON,IDAY)
      CALL GETTIM (IHR,IMIN,ISEC,I100TH)
      write(5,30) FILE5,IMON,IDAY,IYR,IHR,IMIN,LOCATION,MASTER
   30 FORMAT ('ASCII FILENAME: ',A24,'  SIMULATION RUN MADE: 'I2,'-',I2,&
	&'-',I4,' at ',I2,':',I2,/,'Description of sub-basin: ',A80,/,&
	&'Input master filename = ',A36,/&
	&'INPUT FILES FOR METEOROLOGICAL STATION, RESERVOIR,&
        & AND HRU INFORMATION')
!   ****   ECHO PRINT NAMELIST VALUES
      write(5,33)file2,pindx,file3,tindx,file4,etindx,file6,ystart,&
      &yend,nplots,IPLOTS,output,LZDEPTH
   33 format('precipitation: filename= ',A24,', station index= 'I6,/,&
      &'temperature: filename = ',A24,&
      &', station index= ',I6,/,'reference ET: filename = ',&
      &A24,', station index= ',I6,/,'water-use coefficients:  &
      &filename = ',A24,//,'Year Simulaton Begins=',i5,' and Ends= &
      &',I6,//,'OTHER INFORMATION',/,'Total No. of HRUs= ',I2,/,'No&
      &. of HRUs irrigated= ',I2,/,'output code=',I2,'; 6=monthly, 5=ann&
      &ual values in HRU balances'/,'Lower Zone Soil Depth= ',f4.1,' ft.'/)
      write (5,32)HMAX,AL,W,S,DSEPRT,MAXSEPRT
   32 format('TYPICAL RESERVOIR CHARACTERISTICS',/,'maximum height =',f5.1,&
      &' ft., bottom length =',f5.0,' ft. & width =',f5.0,' ft.',/,&
      &'ss=',f5.1,':1, and seepage rate= ',f5.3,' minimum and ',f5.3,&
      &' maximum at full pool,in./day',/)
	    PREVYR = YSTART
      YEARS = YEND-YSTART+1
      GOTO (55,56,55,56,55,56) OUTPUT
!   *****  creates monthly or annual output files for surface and percolation depths for the reservoir and each HRU
!              ******************************************************************
55    FILE9=TRIM(FILE8)//AS 
      open(4,file=file9,status='UNKNOWN')
!     *****   added Nov. 1989 file for annual surface excesses
!     *****
      FILE9=TRIM(FILE8)//PAB
      open(30,file=file9,status='UNKNOWN')   
!     ******************************************************************
!     *****
!     *****   added Sep 03, 1993 files for deep percolation amounts
!     *****    including reservoir seepage.
!     *****
      FILE9=TRIM(FILE8)//AP 
      open(7,file=file9,status='UNKNOWN')
!     *****     
!     ******************************************************************
      GOTO 60
!     ******************************************************************
!     *****
!     *****   added November 30, 1989 file for monthly surface excesses,
!     *****    revised September 03, 1993 to add NET reservoir evaporation.
!     *****
   56 FILE9=TRIM(FILE8)//MS 
      open(6,file=file9,status='UNKNOWN')
!     *****
!     *****   added Sep 03, 1993 files for deep percolation amounts
!     *****    including reservoir seepage.
      FILE9=TRIM(FILE8)//MPE
      open(8,file=file9,status='UNKNOWN') 
!     *****
!     ******************************************************************
!     *****
!     *****   READ HRUS INPUT PARAMETERS
!     *****        NPLOT=NUMBER OF THE HRU
!     *****        ISOIL=SCS IRRIGATION SOIL CLASS ON HRU
!     *****        LU(I,LY)= 6-YEAR CROP SEQUENCE FOR HRU NUMBEREED NPLOT
!     *****        AREA=AREA IN ACRES IN RESERVOIR WATERSHED
!     *****        POND=INDICATOR FOR HRU FLOWING INTO RESERVIOR
!     *****        TCNF(V) = INDICATOR FOR RCN ADJUSTMENT FOR TERRACED CONDITION OR OTHER CONDITION ON HRU
!     *****
!     ******************************************************************
!     *****
   60 WRITE (5,62)
   62 FORMAT ('INFORMATION for each HRU (acres= amount of each HRU i&
                        &n drainage area of reservoir)',/,'No. soil 6-year cropping SEQUENCE  &
           &acres  2=Drains Into Reservoir,1=Does Not;&
	   & 1.00=Not Terraced; LT 1.0=Terraced; GT 1.0 for other condit&
	   &ions') 
      DO 72 I=1,NPLOTS
      READ (1,*) NPLOT(I),ISOIL(I),(LU(I,LY),LY=1,6),AREA(I),POND(I),TCNF(I)  
!     *****   ECHO PRINT INDIVIDUAL HRU INPUT PARAMETERS
      WRITE (5,71) NPLOT(I),ISOIL(I),(LU(I,LY),LY=1,6),AREA(I),POND(I),&
            TCNF(I)
   71 FORMAT (I2,I5,6I4,F9.0,I5,F8.2)
   72 END DO
      WRITE (5,137) 
  137 FORMAT(/,'Crop No.  Crop Name')
      DO IJ=1,10
      WRITE(5,138) IJ,KROP(IJ)
      END DO
  138 FORMAT(I4,6X,A16)
!     *****
!     ******************************************************************
!     *****
!     ***** ECHO IRRIGATED HRUS INFORMATION, ADDED SEPTEMBER 15,1993
!     *****  IPLOTS = TOTAL NO. OF HRUS IRRIGATED
!     *****  IRGPLT = NO. OF HRU IRRIGATED
!     *****  PSCH = % AVAILABLE SOIL MOISTURE IN UPPER ZONE WHEN IRRIGATION IS ADDED
!     *****  ARATE = NET DEPTH OF IRRIGATION ADDED EACH TIME, INCHES
!     *****
      IF (IPLOTS.EQ.0) GOTO 83
!     *****
!     *****  OPEN OUTPUT FILE FOR IRRIGATION WATER USE, IF ONE OR MORE
!     *****  HRU IS IRRIGATED.
!     *****
      GOTO (76,73,76,73,76,73) OUTPUT
!           opens output file for irrigation water use by month or annually, Stationirrig.out
   73 FILE9=TRIM(FILE8)//MIRR
      open(9,file=file9,status='UNKNOWN') 
      GOTO 78
   76 FILE9=TRIM(FILE8)//AIRR
      open(10,file=file9,status='UNKNOWN')
   78 WRITE (5,79)
   79 FORMAT (/'INFORMATION for Irrigated HRU(s)',/,' HRU No. at %asm&
	& add inches')
      DO 81 IR=1,IPLOTS
      READ (1,*) IRGPLT,PSCH(IRGPLT),ARATE(IRGPLT)
      WRITE (5,82) IRGPLT, PSCH(IRGPLT), ARATE(IRGPLT)
      81  END DO
  82  FORMAT(I6,3x,F7.0,F9.2) 
!  *****************************************************************
!     *****
!     *****  READ IN HISTORICAL OR ASSUMED LAND USE FOR POSTPROCESSING
!     *****  TO ESTIMATE SURFACE AND PERCOLATION/GROUNDWATER YIELD.
!     *****  NEW SECTION ADDED SEPTEMBER 21, 1993  PLU=% HRU
!     *****
   83 GOTO (90,90,84,84,97,97) OUTPUT       
   84 WRITE (5,85)
   85 FORMAT (/,'RESERVOIR AND HRU INFORMATION YEAR-BY-YEAR IN&
     &SUB-BASIN&
     &',/,'     no.  annual amount of each HRU in percent of area i&
     &n sub-basin')
      WRITE (5,92)
      LYEAR=999
      open(12,file='TEMP',status='UNKNOWN')
      DO  89 J=1,YEARS
      READ (1,*) YEAR, NPD, (PLU(I),I=1,NPLOTS)
      WRITE (12,87) YEAR, NPD,(PLU(I),I=1,NPLOTS)
   87 FORMAT (I4,I3,24F5.1)        
      WRITE (5,88) YEAR, NPD,(PLU(I),I=1,NPLOTS)
   88 FORMAT(I4,I4,24F5.1)
   89 CONTINUE
      GOTO 96
   90 open(12,file='TEMP',status='UNKNOWN')
      WRITE (5,91)
   91 FORMAT (/,'RESERVOIR AND HRU INFORMATION IN SUB-BASIN',/,&
     &'     no.         amount of each HRU in percent of area in su&
     &b-basin')
      WRITE (5,92)
   92 FORMAT ('year pnds  01   02   03   04   05   06   07   08   09   1 &
     &0   11   12   13   14   15   16   17   18   19   20   21   22   23 &
     &   24')
      READ (1,*) YEAR, NPD, (PLU(I),I=1,NPLOTS)
      WRITE (5,95) YEAR,NPD,(PLU(I),I=1,NPLOTS)
      LYEAR=YEAR
      DO 94 J=1,YEARS
      YEAR = YSTART-1+J
      WRITE (12,93) YEAR, NPD,(PLU(I),I=1,NPLOTS)
   93 FORMAT (I4,I4,24F5.1)        
   94 CONTINUE
   95 FORMAT(I4,I4,24F5.1)
   96 CLOSE (12,STATUS='KEEP')
   97 CONTINUE
!     *****   INITIALIZE VARIABLES
      DO 110 I=1,25
      DO 100 J=2,9
      IF (J.LE.4) PRECAC(I,J) = 0.0
  100 RUNACC(I,J) = 0.0
  110 CONTINUE
  !     *****
!     *****************************************************************
!     *****
      WRITE (5,122) KADJ
  122 FORMAT(/,'Original Water-Use Coefficients for Crops ADJUSTED&
            & by factor of',f5.2/,'Week/Crop 1    2    3    4    5    6    7   &
     & 8    9   10')
      DO 124 IJ=1,53
      WRITE (5,123) IJ,(KADJ*KCROP(KL,IJ),KL=1,10)
  123 FORMAT(I3,4X,10F5.2)  
  124 CONTINUE 
      WRITE (5,125) RCNADJ
  125 FORMAT(/,'Original Runoff Curve Number II for Land Uses ADJUSTED&
              & by factor of',f5.2,/,'LU/Month 1    2    3    4    &
      &5    6    7    8    9   10   11   12')
      DO 126 IJ=1,10
      WRITE (5,121) IJ,(RCNADJ*RCNII(IJ,KL),KL=1,12)
  121 FORMAT(I3,4X,12F5.1)  
  126 CONTINUE 
      WRITE (5,129) RESADJ
  129 FORMAT(/,'Original Residue Factor for Land Uses ADJUSTED by&
      & factor of',f5.2,/,'LU/Month 1    2    3    4    5    6    7   &
     & 8    9   10   11   12')
      DO 128 IJ=1,10
      WRITE (5,135) IJ,(RESADJ*RES(IJ,KL),KL=1,12)
  135 FORMAT(I3,4X,12F5.2)  
  128 CONTINUE 
      TERRACEDAREA=0.0
!     ***** INITIALIZE SOME VALUES
      DO 130 II=1,NPLOTS
      IF(POND(II).NE.1) DA = DA+AREA(II)
      IF(POND(II).EQ.2.AND.TCNF(II).LT.1.) THEN
           TERRACEDAREA=TERRACEDAREA+AREA(II)/640.
	ENDIF   
      TPAREA = TPAREA+AREA(II)
      T(II) = 0.0
      EO(II) = 0.0
      IACCTT(II) = 0.0
      DSRNFF(II) = 0.0
      AINTER(II) = 0.0
      AAETRS(II) = 0.0
      ACHSOM(II) = 0.0
      DSPERC(II) = 0.0
      
!     *****  THE FOLLOWING LINE WAS ADDED IN SEPTEMBER, 1982
      SOIL = ISOIL(II)
!     *****   FOLLOWING 2 LINES REVISED SEPTEMBER, 1982
      SMLZ(II) = 0.65*AVLFCL(SOIL)*LZDEPTH + PWPLZ(SOIL)*LZDEPTH
      SMUZ(II) = 0.65*AVLFCU(SOIL) + PWPUZ(SOIL)
      SMGWZ(II) = 6.30
      SMPD(II) = SMLZ(II)+SMUZ(II)
  130 CONTINUE
!     ******************************************************************
!     *****   SUBROUTINE VOLRT CALCULATES THE DIMENSIONS OF THE
!     *****    THE RESERVOIR USING THE GIVEN INPUT INFORMATION.
      CALL VOLRT (AL,W,S,H,HMAX,DSEPRT,A1,A2,A3,A4,A5,PSAREA,VOLMAX)
!     *****
!     *****   PRINT INPUT PARAMETERS
!     *****
      WRITE (5,150) LOCATION,YSTART,YEND,AL,W,S,HMAX,&
       &VOLMAX/12.,PSAREA,DSEPRT,MAXSEPRT,DA
  150 FORMAT (///,'STATION:  ',A64,2X,I4,' TO ',I4/,&
     &/5X,'TYPICAL RESERVOIR VARIABLES:',/10X,'(A) BASE DIMENSIONS-- ',&
     &F5.0,'FEET BY ',F5.0,'FEET',/10X,'(B) SIDE SLOPE-- RUN:RISE = ',&
     &F4.1,':1',/,10X,'(C) MAXIMUM DEPTH-- ',F5.1,' FEET',/10X,'(D)&
        & MAXIMUM RESERVOIR VOLUME-- ',F9.2,' ACRE-FEET',/10X,'(E) MAXIMUM RESERVOIR SURFACE A&
     &REA-- ',F8.2,' ACRES',/10X,'(F) SEEPAGE RATE--',F5.2,&
     &' MINIMUM TO MAXIMUM AT MAXIMUM DEPTH OF',F5.2,' INCHES/DAY'&
     &,/10X,'(G) DRAINAGE AREA--',F7.1,' ACRES'//,'HRUs AREA VARIABLES:')
      DO 180 J=1,NPLOTS
      PLAREA = AREA(J)
      SOIL = ISOIL(J)
      CNADJ=RCNII(LU(J,1),1)*RCNADJ*TCNF(J)
      PLIT = NO
      PTER = NOT
      IF (POND(J).GT.1) PLIT = BLNK
      IF (TCNF(J).LT.1.) PTER = BLNK
      WRITE (5,160) J,PLAREA,(KROP(LU(J,I)),I=1,6),SOIL,PLIT,PTER,& 
           RES(LU(J,1),1)*RESADJ,CNADJ
  160 FORMAT (/5X,'HRU ',I2//10X,'(A) AREA IN RESERVOIR WATERSHED--  ',&
     &F7.1,' ACRES'/10X,'(B) 6-YEAR LAND-USE SEQUENCE -- ',2A15,/,14X,4A15,/,&
     &10X,'(C) SOIL TYPE--',I3,' (SCS IRRIGATION CLASS)'/10X,'&
     &(D) CONSERVATION PRACTICES--',A2,' FLOW INTO RESERVOIR; ',A3,' TERRACED;'/,41X,&
     &'BEGINNING RESIDUE FACTOR =',F4.2,/10X,'(E) RUNOFF CURVE NUMBER:&
           & AMC II FOR 1ST YEAR CROP FOR MONTH 1  = ',F4.1)
!     *****
!     *****************************************************************
!     *****
!     *****  PRINT IRRIGATION INFORMATION FOR HRU
      WRITE (5,165) PSCH(J),ARATE(J)   !,IMOBEG(J),IDYBEG(J),IMOEND(J),&     IDYEND(J)
  165 FORMAT (10X,'(F) IRRIGATED UPPER ZONE AVAILABLE SOIL MOISTURE BELO&
     &W: ',F3.0,'%'/16X,'WITH',F5.2,' INCHES')
    180 CONTINUE
!     *****
!     *****************************************************************
!     ***** OPEN FILE FOR DAILY OUTPUT OF LAST YEAR OF SIMULATION.
!     ***** ADDED OCTOBER 13, 1993
      open(16,file='DAILY.OUT',status='UNKNOWN') 
      WRITE (16,181) LOCATION,YEND
      DO 176 L9=31,40
      WRITE(L9,175)FILE19, ISOIL(1)
  176 CONTINUE
      175 FORMAT(A9,I3)
      
  181 FORMAT ('Sub-basin simulated: 'a48,/,&
     &'Daily information for ',I4,', the last year of the simulation per&
     &iod.',//,25X,'--------   HRU 1    --------   --------   HRU 2    -&
     &-------   --------   HRU 3    --------   --------   HRU 4    -----&
     &---   --------   HRU 5    --------   --------   HRU 6    -------- &
     &  --------   HRU 7    --------   --------   HRU 8    --------   --&
     &------   HRU 9    --------   --------   HRU 10    -------   ------&
     &--   HRU 11    -------   --------   HRU 12    -------   --------  &
     & HRU 13    -------   --------   HRU 14    -------   --------  HRU &
     &15     -------   --------   HRU 16    -------   --------   HRU 17 &
     &   -------   --------   HRU 18    -------   --------   HRU 19    -&
     &------   --------   HRU 20    -------   --------   HRU 21    -----&
     &--   --------   HRU 22    -------   --------   HRU 23    -------  &
     & --------   HRU 24    -------')
      WRITE (16, 182) 
  182 FORMAT ('MO DY TMX TMN PREC. PET IRRG.INTC. RUNF.PERC.AET SLMO. IR&
     &RG.INTC. RUNF.PERC.AET SLMO. IRRG.INTC. RUNF.PERC.AET SLMO. IRRG.I&
     &NTC. RUNF.PERC.AET SLMO. IRRG.INTC. RUNF.PERC.AET SLMO. IRRG.INTC.&
     & RUNF.PERC.AET SLMO. IRRG.INTC. RUNF.PERC.AET SLMO. IRRG.INTC. RUN&
     &F.PERC.AET SLMO. IRRG.INTC. RUNF.PERC.AET SLMO. IRRG.INTC. RUNF.PE&
     &RC.AET SLMO. IRRG.INTC. RUNF.PERC.AET SLMO. IRRG.INTC. RUNF.PERC.A&
     &ET SLMO. IRRG.INTC. RUNF.PERC.AET SLMO. IRRG.INTC. RUNF.PERC.AET S&
     &LMO. IRRG.INTC. RUNF.PERC.AET SLMO. IRRG.INTC. RUNF.PERC.AET SLMO.&
     & IRRG.INTC. RUNF.PERC.AET SLMO. IRRG.INTC. RUNF.PERC.AET SLMO. IRR&
     &G.INTC. RUNF.PERC.AET SLMO. IRRG.INTC. RUNF.PERC.AET SLMO. IRRG.IN&
     &TC. RUNF.PERC.AET SLMO. IRRG.INTC. RUNF.PERC.AET SLMO. IRRG.INTC. &
     &RUNF.PERC.AET SLMO. IRRG.INTC. RUNF.PERC.AET SLMO.')  
!     *****
!     *****************************************************************
!     *****
!     *****   ***** ENTER YEARLY LOOP *****
!     *****
      LY=1
      DO 960 NY=1,YEARS
!     *****
!     *****   INITIALIZE VARIABLES
      AVGPNDFULL=0.0
      SMDI = 0
      PERS = 0
      SPER = 0
      MAXVOL = 0.0
      LKEVPT = 0.0
      VOLCHG = 0.0
      PETACT(13) = 0.0
      NDOY=0
      DO 210 J=1,9
      DO 200 I=1,13
      DO 190 K=1,NPLOTS
  190 SMACCT(I,J,K) = 0.0
  200 PDACCT(I,J) = 0.0
  210 CONTINUE
  DO 220 K=1,NPLOTS
      PCROP(K) = LU(K,LY)
  220 PEACCT(K) = 0.0
      WRITE (5,260)
  260 FORMAT (//,26X,'****** ANNUAL SUMMARY ******')
!     *****
!     *****
!     *****   ***** ENTER MONTHLY LOOP *****
!     *****
!     *****  MONTHLY LOOP ALTERED IN SEPTEMBER, 1982 TO ELIMINATE
!     *****  MSTART FROM THE VARIABLE LIST (NAMELIST OMEGA).
!     *****   FOLLOWING LINE REVISED IN SEPTEMBER, 1982
      DO 710 NM=1,12
      PETACT(NM)=0.0
!     *****
!     *****   READ DAILY METEOROLOGICAL DATA FOR ONE MONTH
  300 READ (2,*,END=970) PSTIND,YEAR,MONTH,(PREC(I),I=1,31)
      IF (PSTIND.NE.PINDX) GOTO 320
      IF (YEAR.LT.YSTART) GOTO 300
  305 READ (3,*,END=970) TSTIND,YEAR,MONTH,(TMAX(I),TMIN(I),I=1,31)
      IF (TSTIND.NE.TINDX) GOTO 330
      IF (YEAR.LT.YSTART) GOTO 305
  307 READ (15,*,END=970) ETSTIND,YEAR,MONTH,(ETrPM(I),I=1,31)
      IF (ETSTIND.NE.ETINDX) GOTO 336
      IF (YEAR.LT.YSTART) GOTO 307      
      IF (YEAR.GT.YEND) GOTO 970
      GOTO 340
  320 WRITE (*,325) PINDX, FILE2, PSTIND
  325 FORMAT(/,' The precipitation station index specified in the input& 
     &file is ',I6,',',/,' however, the precipitation station index in f&
     &ile, ',A12,' is ',I6,'.',/,' THEREFORE, YOUR RUN WAS TERMINATED.  &
     &PLEASE CORRECT THE ERROR.')
      GOTO 2900
  330 WRITE (*,335) TINDX, FILE3, TSTIND
  335 FORMAT(/,' The temperature station index specified in the input fi&
     &le is ',I6,',',/,' however, the temperature station index in file,&
     & ',A12,' is ',I6,'.',/,' THEREFORE, YOUR RUN WAS TERMINATED.  PLEA&
     &SE CORRECT THE ERROR.')
      GOTO 2900
  336 WRITE (*,337) ETINDX, FILE4, ETSTIND
  337 FORMAT(/,' The reference ET station index specified in the&
     &  input file is ',I6,',',/,' however, the reference ET station index in file,&
     & ',A12,' is ',I6,'.',/,' THEREFORE, YOUR RUN WAS TERMINATED.  PLEA&
     &SE CORRECT THE ERROR.')
      GOTO 2900      
  340 NDIM(2) = 28
      IF (NM.EQ.2.AND.TMAX(29).LT.900) NDIM(2) = 29
      NDAYS = NDIM(NM)
!     *****
!     *****   ***** ENTER DAILY LOOP *****
!     *****
      DO 670 ND=1,NDAYS
!     *****
!     *****   THE FOLLOWING STATEMENTS CORRECT FOR MISSING DATA
!     *****    IN INPUT FILE.  MISSING DATA ENTERED AS 999, 99.99, OR 9.99 IN FILES.
      IF (TMAX(ND).GT.150.0) TMAX(ND) = PDT
      IF (TMIN(ND).GT.150.0) TMIN(ND) = PDT
      IF (PREC(ND).GT.99.97) PREC(ND) = 0.0
      IF (ETrPM(ND).GT.9.97) ETrPM(ND) = 0.0
      TAVG=(TMAX(ND)+TMIN(ND))/2.
      STRVOL = 0.0
      PETD=ETrPM(ND)
      PETX=ETrPM(ND)
!     ***** PET AMOUNT IN STORAGE ACCOUNT
      PETACT(NM) = PETACT(NM)+PETD
      LAKEVP=ETrPM(ND)*1.17
      PRECIP=PREC(ND)
      NDOY=NDOY+1
      WEEK=1+NDOY/7
!     *****
!     *****   ***** ENTER INDIVIDUAL HRU LOOP *****
!     *****
      DO 580 JJ=1,NPLOTS
!     *****
      DPERC=0.0
      EXCESS = 0.0
      STRNOF = 0.0
      SOIL = ISOIL(JJ)
      KROPKO = KCROP((LU(JJ,LY)),WEEK)*KADJ
      ZSMUZ = SMUZ(JJ)
      ZPWPUZ = PWPUZ(SOIL)
      ZAVFCU = AVLFCU(SOIL)
      RCN2 = RCNII((LU(JJ,LY)),NM)*RCNADJ*TCNF(JJ)
      MUL=RES((LU(JJ,LY)),NM)*RESADJ
      ZSM = SM(JJ)
      SNOWPACK = PACK(JJ)
      IF(TAVG.LT.32.) SNOWPACK=SNOWPACK+PRECIP
!     *****   SUBROUTINE SNOWMELT CALCULATES THE MOISTURE ADDED TO THE HRU DUE TO SNOWMELT
!     *****   ON THE AREA.  SNOW IS MELTED BEFORE RUNOFF IS CALCULATED SO SNOWMELT RUNOFF
!     *****   CAN BE EVALUATED AS A PART OF THE OPERATION OF AN HRU.
      MELT=0.0
      IF(SNOWPACK.GT.0..AND.TAVG.GT.32.) &
      CALL SNOWMELT (PRECIP,MELT,SNOWPACK,TAVG)
      RAIN = PRECIP+MELT
!     *****
!******************************************************************
!     *****
!     *****  IRRIGATION SCHEDULING SECTION.  
!    ARATE = AMOUNT OF IRRRIGATION WATER TO ADD TO HRU(JJ) 
!    KROPKO = WATER-USE-COEFFICIENT FOR HRU for the week of the year; NO IRRIGATION IF LESS THAN 0.2
!    IPD = IRRIGATED THE PREVIOUS DAY IF = 1; CANNOT IRRIGATE ON TWO CONSECUTIVE DAYS
!    RAIN = AMOUNT OF RAIN TODAY; IF GREATER THAN 0.2 INCH, THEN NO IRRIGATION TODAY
!    TAVG = TODAY'S AVERAGE TEMPERATURE; IF LESS THAN 40 F, THEN NO IRRIGATION TODAY
!    FROZE FOR FROZEN SOIL; IF 1 SOIL IS FROZEN AND NO IRRIGATION TODAY
!    PACK = SNOWPACK FOR SNOW ON THE GROUND; NO IRRIGATION IF THERE IS SNOW ON THE GROUND
!    NM = MONTH OF THE YEAR TO CONTROL WHEN IRRIGATION IS DONE
!    ND = DAY OF THE MONTH TO CONTROL WHEN IRRIGATION IS DONE.
!    LU(JJ,LY) = LAND USE ON HRU(JJ) AND LY IS THE YEAR IN THE 6-YEAR ROTATION
!     *****
  365 IF(ARATE(JJ).LT.0.01) GOTO 384 !HRU IS NOT IRRIGATED.
      IF (KROPKO.LT.0.2) GOTO 384    !CANNOT IRRIGATE IF AET DEMAND IS LOW.
      IF (IPD(JJ).LT.2) GOTO 384     !CANNOT IRRIGATE MORE OFTEN THAN EVERY THREE DAYS.      
      IF (RAIN.GT.0.2) GOTO 384      !IRRIGATION ALLOWED ON DAYS WITH SMALL RAIN EVENTS.
      IF (TAVG.LT.40.) GOTO 384
      IF (FROZE.EQ.1) GOTO 384
      IF (PACK(JJ).GT.0.0) GOTO 384
      IF (LU(JJ,LY).EQ.10) GOTO 377  ! IRRIGATED CORN
      IF (LU(JJ,LY).EQ.3) GOTO 377   ! DRYLAND CORN THAT COULD BE IRRIGATED 
      IF (LU(JJ,LY).EQ.4) GOTO 377   ! SORGHUM
      IF (LU(JJ,LY).EQ.5) GOTO 377   ! SOYBEANS 
      GOTO 381
  377 IF (NM.LT.6.OR.NM.GT.8) GOTO 384     !NO IRRIGATIONWATER SUMMER CROPS  BEFORE JUNE OR AFTER AUGUST.
      IF (NM.EQ.6.AND.ND.LT.1) GOTO 384   !NO IRRIGATION WATER SUMMER CROPS BEFORE JUNE 1.
      IF (NM.EQ.8.AND.ND.GT.31) GOTO 384   !NO IRRIGATION WATER SUMMER CROPS AFTER AUGUST 31.      
  381 SWTCH = 100*(((SMUZ(JJ)-PWPUZ(SOIL))&
      +(SMLZ(JJ)-PWPLZ(SOIL)*LZDEPTH))/((AVLFCU(SOIL))&
      +(AVLFCL(SOIL)*LZDEPTH)))
      IF (SWTCH.GT.PSCH(JJ)) GOTO 384
      AMTIRR = ARATE(JJ)
      IPD(JJ)=0
      GOTO 385
  384 AMTIRR = 0.
      IPD(JJ)=IPD(JJ)+1
!     *****
!     ******************************************************************
!     *****  ONLY HALF OF AMOUNT OF IRRIGATION IS ADDED TO RAIN FOR CALCULATION OF RUNOFF.
!     ***** IRRIGATION APPLICATION IS ASSUMED TO BE AT RATE CLOSER TO INFILTRATION RATE OF SOIL.
!     ***** SO, RUNOFF FROM IRRIGATION APPLICATIONS SHOULD BE LESS THAN FOR RAIN AND RAIN+IRRIGATION EVENTS.
  385 RAIN = RAIN+ 0.5*AMTIRR
      IF (RAIN) 360,360,350
!     *****   SUBROUTINE RNOFRT EVALUATES PRECIPITATION EXCESS USING
!     *****   THE SCS EQUATION.
  350 CALL RNOFRT (ZAVFCU,ZPWPUZ,RAIN,RCN2,RNOF,ZSMUZ)
      GOTO 362
  360 RNOF = 0.0
!     *****  REMAINDER OF AMOUNT OF IRRIGATION ADDED TO RAIN FOR WATER BALANCE PURPOSES AFTER RUNOFF CALCULATIONS
  362 RAIN = RAIN + 0.5*AMTIRR
!     *****  
!     *****   EVALUATE LOSSES BY INTERCEPTION PROCESSES
!     *****************************************************************
!     *****  INTERCEPTION INCLUDES LIQUID PRECIPITATION THAT IS ON THE SURFACE OF RESIDUE AND/OR PLANTS THAT IS
!     *****  ASSUMED TO EVAPORATE AT THE RATE OF PET FOR THE DAY.  IF PET IS LESS THAN PET FOR THE DAY, THE UNEVAPORATED
!     *****  REMAINS IN THE INTERCEPTION STORAGE AMOUNT, IACCT, AT THE END OF THE DAY AND CARRIES FORWARD.
!     ***** IF SNOW EVAPORATION OCCURS, INTERCEPTION EQUALS SNOVAP FOR 
!     ***** THE DAY AND THE INTERCEPTION STORAGE ACCOUNT DOES NOT CHANGE.
!     ***** THE SNOVAP IS SUBTRACTED FROM SNOWPACK THE SNOWPACK ON THE HRU.  SNOW EVAPORATION IS THE ONLY 
!     ***** INTERCEPTION MECHANISM WHEN THERE IS A SNOVAP.  NO OTHER WATER IS LOST FROM THE HRU ON THAT DAY. 
!     *****
      IACCT = IACCTT(JJ) !  IACCT= AMOUNT OF INTERCEPTION STORAGE FOR HRU(JJ) AT BEGINNING OF DAY.
      CALL INTERCEPTION (JJ,INTERC,IACCT,KROPKO,RAIN,PETD,PET,TAVG,&
            MUL,SNOWPACK,SNOVAP,CONSTANT)
	IACCTT(JJ) = IACCT  ! AMOUNT OF WATER LEFT IN INTERCEPTION ACCOUNT AT THE END OF THE DAY.
        PACK(JJ)=SNOWPACK  !UPDATE SNOWPACK AFTER SNOW EVAPORATION OCCURS
!     *****
!     *****   EVALUATE INFILTRATION INTO THE UPPER ZONE
      PERC = RAIN-RNOF-INTERC
      UZEVAP = 0.0
!     *****   EVALUATE IF WATER CASCADED TO LOWER ZONE
      SMUZ(JJ)= +PERC+SMUZ(JJ)
      IF (SMUZ(JJ).GT.FCU(SOIL)) GOTO 390
      PERCL = 0.0
      GOTO 395
!     *****   EVALUATE GRAVITATIONAL WATER FROM UPPER ZONE
  390 PERCL = SMUZ(JJ)-FCU(SOIL)
	SMUZ(JJ)=FCU(SOIL)
!     *****
!     *****   IF THE CROP IS DORMANT OR THE SOIL LIES FALLOW, SOIL
!     *****    EVAPORATION IS EVALUATED
  395 IF (KROPKO.LE.0.0) GOTO 510
      T(JJ) = 0.0
!     *****   MODIFY PET BY THE PLANT CONSUMPTIVE USE COEFFICIENT AND
!     *****   INTERCEPTION AMOUNT THAT SATISFIES PET TO OBTAIN AET BEFORE
!     *****   CHECKING TO SEE IF IT IS LIMITED FURTHER BY SOIL MOISTURE
!     *****   AVAILABILITY
      IF (SNOVAP) 397,397,396
  396 AET = 0.0
      GOTO 510    
  397 IF (PET) 399,399,400
  399 AET = 0.0
      GOTO 405
  400 AET = KROPKO*PET  
!     *****   CHECK WHETHER SOIL MOISTURE LIMITS AET FROM THE UPPER ZONE
!     *****
!     *****   ONCE AVAILABLE SOIL MOISTURE (ASM)
!     *****   IS BELOW 30%, THERE IS A LINEAR DECREASE IN THE RATIO OF
!     *****   AET/PET FROM 1 TO 0 AS ASM DECREASES FROM 30% TO 0% IN THE UPPER ZONE
!     *****   THE DECREASE IN AET/PET BEGINS AT 50% OF ASM IN THE LOWER ZONE
!     *****
!     *****   CALCULATE AET FROM THE UPPER ZONE 
  405 IF (SMUZ(JJ)-(0.3*(AVLFCU(SOIL))+PWPUZ(SOIL))) 410,410,415
!              DRY CONDITIONS
  410 AVAILU = SMUZ(JJ)-PWPUZ(SOIL)
      IF (AVAILU.LE.0.0) AVAILU = 0.0
      AETUZ = 0.4*AET*(AVAILU/(0.3*AVLFCU(SOIL))) !40% demanded from the upper foot when soil is below 30% AMC
      AET=AET-AETUZ  !Remainder of demand for AET passed to lower zone when not satisfied in upper zone  
      GOTO 425
!               WET CONDITIONS
  415 AETUZ = 0.4*AET !40% from the upper foot when soil is above 30% AMC
      AET=AET-AETUZ
!     *****   EVALUATE AVAILABLE WATER IN THE LOWER ZONE
  425 AVAILL = SMLZ(JJ)-PWPLZ(SOIL)*LZDEPTH
      IF (AVAILL.LE.0.0) AVAILL = 0.0
!     *****   CHECK WHETHER SOIL MOISTURE LIMITS AET FROM THE LOWERZONE  IT BEGINS TO DECREASE WHEN LESS THAN 50% AMC
      IF (SMLZ(JJ)-(0.5*AVLFCL(SOIL)*LZDEPTH+PWPLZ(SOIL)*LZDEPTH))&
      420,420,430
!     *****   CALCULATE AET FROM THE LOWER ZONE WHEN LIMITED BY SOIL MOISTURE.
!     *****
!               DRY CONDITIONS
  420 AETLZ = AET*(AVAILL/(0.5*AVLFCL(SOIL)*LZDEPTH))
      GOTO 460
!              WET CONDITIONS      
  430 AETLZ = AET
!     *****
!     *****   EVALUATE SOIL MOISTURE
  460 SMUZ(JJ) = SMUZ(JJ)-AETUZ
      SMLZ(JJ) = SMLZ(JJ)-AETLZ+PERCL
! Modify for drainage additions	  
  480 IF(SMLZ(JJ).LT.(PWPLZ(SOIL)+0.7*AVLFCL(SOIL))*LZDEPTH) THEN
      DPERC=0.0
    ELSEIF(SMLZ(JJ).GT.(PWPLZ(SOIL)+AVLFCL(SOIL))*LZDEPTH) THEN
      DPERC=(SMLZ(JJ)-(PWPLZ(SOIL)+AVLFCL(SOIL))*LZDEPTH)
	  SMLZ(JJ)=SMLZ(JJ)-DPERC 
	ELSE
      DPERC =(SMLZ(JJ)/LZDEPTH-(PWPLZ(SOIL)+&
              0.67*AVLFCL(SOIL)))**3.5
      SMLZ(JJ)=SMLZ(JJ)-DPERC
      END IF
      GOTO 570
!     *****   CALCULATE EVAPORATION FROM SOIL SURFACE FOR PERIODS
!     *****   WHEN KROPKO=0.0
!     *****
!     ******************************************************************
!     *****
!     *****   EFFECT OF RESIDUE ON EVAPORATION ADDED SEPTEMBER 15, 1993
!     *****   MUL = DECIMAL REDUCTION IN STAGE 1 & STAGE 2 EVAPORATION
!     *****   DURING NON-GROWING OR FALLOW SEASON WHEN KCROP=0.0
!     *****
!     ******************************************************************
!     *****
  510 AETUZ = 0.0
      AETLZ = 0.0
      IF (SNOVAP.GT.0.0) GOTO 540  !NO SOIL EVAPORATION ON DAYS WITH SNOW EVAPORATION.
!     *****   FOR LOW-PET DAYS, STAGE 1 EVAPORATION IS REDUCED
!                 http://www.kimberly.uidaho.edu/water/papers/evapotranspiration/ASCE_JIDE_2005_Allen_FAO_evaporation.pdf 
      IF(PETD.GT.0.20) THEN
      S1=U(SOIL)
      S2=C(SOIL)
      ELSE
      S1=U(SOIL)*(PET/0.20)**0.5
      S2=C(SOIL)*(PET/0.20)**0.5
      END IF
      IF (SMUZ(JJ).LE.(FCU(SOIL)-S1)) GOTO 520
!     *****   CALCULATE STAGE 1 SOIL EVAPORATION (WET CONDITIONS)
      UZEVAP = (1-MUL)*PET
	T(JJ)=1.0
      GOTO 530
!     *****   CALCULATE STAGE 2 SOIL EVAPORATION (CAPILLIARY CONTROLS)
  520 T(JJ) = T(JJ)+1.0
      UZEVAP =(1-MUL)*(S2*((T(JJ)**0.5)-(T(JJ)-1)**0.5))
  530 IF (UZEVAP.GT.((1-MUL)*PET))&
          UZEVAP =(1-MUL)*PET
      IF (UZEVAP.LE.0.0) UZEVAP = 0.0
      IF ((SMUZ(JJ)-PWPUZ(SOIL)-0.3*AVLFCU(SOIL)).LE.UZEVAP)&
           UZEVAP = (SMUZ(JJ)-PWPUZ(SOIL)-0.3*AVLFCU(SOIL))
      GOTO 550
  540 UZEVAP = 0.0
  550 SMUZ(JJ) = SMUZ(JJ)-UZEVAP
      IF (SMUZ(JJ).LE.PWPUZ(SOIL)) SMUZ(JJ) = PWPUZ(SOIL)
      GOTO 460
  570 AETUZ = AETUZ+UZEVAP
!     *****   SM=SOIL MOISTURE IN THE GROWING ZONE, IN INCHES
!!     *****   AETU=ET AMOUNT FROM THE UPPER ZONE (IN.)
!     *****   AETL=ET AMOUNT FROM THE LOWER ZONE (IN.)
!     *****   NDPERC=AMOUNT OF DEEP PERCOLATION (IN.)
!     *****   NIA=INITIAL ABSTRACTION AMOUNT (IN.)
!     *****   NRNOF=PRECIPITATION EXCESS AMOUNT (IN.)
!     *****   STRNOF=PRECIPITATION EXCESS AMOUNT WHICH FLOWS INTO RESERVOIR (IN.)
!     *****   STRVOL=PRECIPITATION EXCESS VOLUME WHICH FLOWS INTO THE RESERVOIR (ACRE-INCHES)
      SM(JJ) = SMUZ(JJ)+SMLZ(JJ)
!     *****SOIL MOISTURE DROUGHT INDEX ROUTINE
!     *****THE FOLLOWING CALCULATIONS DETERMINE A SOIL MOISTURE
!     *****DROUGHT INDEX FOR A GIVEN CROP DURING A PREDETERMINED
!     *****GROWING PERIOD - MBEGIN TO MEND.  IT SUMS THE NUMBER
!     *****OF DAYS THAT SOIL MOISTURE IN THE UPPER ZONE IS LESS THAN
!     *****30 PERCENT OF FIELD CAPACITY AND THE MAXIMUM NUMBER OF
!     *****DAYS THE CONDITION PERSISTS DURING EACH YEAR.
!      IF (JJ.EQ.SKPLOT) GOTO 575
!      IF (CROP.NE.JCROP) GOTO 575
!      IF (NM.LT.MBEGIN.OR.NM.GT.MEND) GOTO 575
!      IF (SMUZ(JJ).GE.(0.3*(AVLFCU(SOIL))+PWPUZ(SOIL))) GOTO 574
!      SMDI=SMDI+1
!      PERS=PERS+1
!      IF (PERS.GT.SPER) SPER=PERS
!      GOTO 575
!  574 PERS=0
  575 AETU(JJ) = AETUZ
      AETL(JJ) = AETLZ
      NDPERC(JJ) = DPERC
      NIA(JJ) = INTERC
      NRNOF(JJ) = RNOF
      TIRRG(JJ) = AMTIRR
      IF (POND(JJ).GT.1) STRNOF = RNOF
      STRVOL = STRVOL+STRNOF*AREA(JJ) 
!******        WRITE DAILY VALUES FOR INPUT TO TERRACE PROGRAM FOR HRUs 1-9
!******        YEAR,MONTH,DAY,PET,(PRECIP + IRRIGATION),INFLOW, CROP COEFFICIENT, RESIDUE FACTOR
	! all water amounts are in inches
	IF (JJ.lt.11)  X=PRECIP+TIRRG(JJ)
	IF (JJ.lt.11) then 
	zz=jj+30
	WRITE(zz,665) YEAR,MONTH,ND,PETD,X,RNOF,KROPKO,MUL
  665 FORMAT(I4,I3,I3,5F8.4)
	ENDIF
	   X=0.
      580 CONTINUE
!     *****
!     *****
!     *****   **** CALCULATION OF SURFACE AREA AND DETERMINATION OF
!     *****          SURFACE EVAPORATION FROM RESERVOIR FACILITY ***
!     *****
      IF (PONVOL.LE.0.0) GOTO 600
!     *****   THE FOLLOWING CALCULATION EXPRESSES THE VOLUME OF WATER
!     *****    IN THE RESERVOIR IN CUBIC FEET.
      V = PONVOL*3630
!     *****        THE FOLLOWING CALCULATIONS DETERMINE THE SURFACE
!     *****   AREA OF THE RESERVOIR AS A FUNCTION OF THE STORAGE VOLUME.
!     *****   AREA IS IN SQUARE FEET AND VOLUME IS IN CUBIC FEET.
!     *****   THE RESERVOIR IS SHAPED LIKE AN INVERTED FRUSTUM OF A
!     *****   PYRAMID. INPUT PARAMETERS TO SIZE THE RESERVOIR ARE
!     *****   LENGTH (AL) AND WIDTH (W) OF THE BASE IN FEET, AND SIDE
!     *****   SLOPES EXPRESSED AS A RATIO OF RUN:RISE.
!     *****   INPUTS TO THE RESERVOIR INCLUDE PRECIPITATION EXCESS
!     *****   AND DIRECT PRECIPITATION ONTO THE SURFACE. LOSSES
!     *****   INCLUDE EVAPORATION, EXFILTRATION, AND OVERFLOWS.
!     *****
!     *****   B2 IS THE AREA OF THE SURFACE WATER IN SQUARE FEET.
      HAPRX = (PONVOL/VOLMAX)*HMAX
  590 VC = A1*HAPRX+A2*HAPRX**2+A3*HAPRX**3
      DV = V-VC
      DVDH = A1+A4*HAPRX+A5*HAPRX**2
      H = HAPRX+DV/DVDH
      IF (ABS(H-HAPRX).LT.0.1) GOTO 600
      HAPRX = H
      GOTO 590
  600 IF (H.GT.HMAX) H = HMAX
      B2 = (W+2.*S*H)*(AL+2.*S*H)
      IF (FROZE.EQ.1) LAKEVP = 0.0
      LKEVPT = LKEVPT+LAKEVP
      TOTLKE(NM) = TOTLKE(NM)+LAKEVP
      SEVAP = B2*(LAKEVP/12.)
!     ***** SEVAP IS THE VOLUME OF WATER EXTRACTED FROM THE RESERVOIR BY FREE SURFACE EVAPORATION.
      IF ((SEVAP/3630.).GT.PONVOL) SEVAP = PONVOL*3630.
      PONVOL = PONVOL-(SEVAP/3630.)
      IF (PONVOL.LE.0.0) PONVOL = 0.0
!     *****  CALCULATES THE DAILY AMOUNT OF SEEPAGE FROM THE RESERVOIR
!     *****  SEEPRATE IS THE DAILY SEEPAGE RATE IN INCHES/DAY
!     *****  SURFACE OF THE RESERVOIR IN ACRE-INCHES PER DAY
!    *****   DSEPRT AND MAXSEPRT ARE THE SEEPAGE RATES AT H=0. AND HMAX, RESPECTIVELY
!    *****   SO, SEEPRATE IS A LINEAR FUNCTION OF DEPTH IN RESERVOIR
!    *****   DASEEP IS THE VOLUME OF SEEPAGE FOR THE DAY IN ACRE-INCHES
      SEEPRATE= DSEPRT+(H/HMAX)*(MAXSEPRT-DSEPRT)
      DASEEP = B2*SEEPRATE/43560.0
      IF (DASEEP.GT.PONVOL) DASEEP = PONVOL
      PONVOL = PONVOL-DASEEP
      IF (PONVOL.LT.0.0) PONVOL = 0.0
!     ****
!     ****   THE VOLUMES OF CALCULATED RUNOFF AND DIRECT PRECIPITATION ARE ADDED TO THE RESERVOIR VOLUME
      PRCPVL = PRECIP*B2/43560.0
!     ****   THE VOLUME OF WATER REMAINING AT THE END OF THE DAY IS  EXPRESSED IN ACRE-INCHES.
      PONVOL = PONVOL+PRCPVL+STRVOL
!     ****
!     ****   THE FOLLOWING STATEMENTS DETERMINE WHETHER THE RESERVOIR HAS
!     ****   OVERFLOWED AND IF SO, THE QUANTITY DISCHARGED
      DSCHRG = 0.0
      IF (PONVOL-VOLMAX) 630,630,610
  610 DSCHRG = PONVOL-VOLMAX
      IF (DSCHRG.GE.PEAK) PEAK = DSCHRG
!     *****   NODSCH=TOTAL NUMBER OF DISCHARGE DAYS
      NODSCH = NODSCH+1
      DSCVOL = DSCVOL+DSCHRG
!     *****   VOLUME CALCULATIONS TO INCREASE THE RESERVOIR SIZE TO HOLD 100% OF THE INFLOW
      PCNTRL = CONTRL*100.0
      VOLCHG = CONTRL*PONVOL-VOLMAX+VOLCHG
      VOLMX1 = VOLMAX+VOLCHG
      VCB = 2*S*HMAX
      VCC = ((4./3.)*S**2.0)-(VOLMX1*3630./HMAX)
      VCD = VCB**2-(4.*VCC)
      VC1 = SQRT(VCD)
      DIM = (VC1-VCB)/2.0
!     *****   WRITE DAILY OVERFLOW MESSAGE
!     *****************************************************************
!     *****
!     *****  RESIZING OF RESERVOIR NOT NEEDED.  THESE LINES
!     *****  WERE COMMENTED OUT SEPTEMBER 08, 1993.   JKK
!     *****
!     *****************************************************************
!     *****
!      WRITE (5,620) NM,ND,YEAR,DSCHRG,VOLMX1,PCNTRL,DIM
!  620 FORMAT (/,1X,I2,'/',I2,'/',I2,' - DISCHARGE OF ',F7.2,' ACRE-IN ',
!     1'REQUIRES VOLUME OF',F8.2,' ACRE-IN FOR ',F6.2,' % CONTROL WHERE AL
!     2 = W = ',F8.2)
      PONVOL = VOLMAX
!     *****
!     *****************************************************************
!     *****
  630 CONTINUE
!     *****
!     *****              UPDATE SOIL MOISTURE ACCOUNTS
!     *****
      DO 632 I3=1,NPLOTS
      SMACCT(NM,2,I3) = SMACCT(NM,2,I3)+PRECIP
      SMACCT(NM,3,I3) = SMACCT(NM,3,I3)+NIA(I3)
      SMACCT(NM,4,I3) = SMACCT(NM,4,I3)+NRNOF(I3)
      SMACCT(NM,5,I3) = SMACCT(NM,5,I3)+NDPERC(I3)
      SMACCT(NM,6,I3) = SMACCT(NM,6,I3)+AETU(I3)+AETL(I3)
      SMACCT(NM,7,I3) = SMACCT(NM,7,I3)+SM(I3)-SMPD(I3)
!     *****
!     ***** IRRIGATION AMOUNT STORAGE ACCOUNT
!     *****
      SMACCT(NM,9,I3) = SMACCT(NM,9,I3)+TIRRG(I3)
!     *****
  632 SMPD(I3) = SM(I3)
!     *****              UPDATE RESERVOIR ACCOUNT
!     *****
      PDACCT(NM,2) = PDACCT(NM,2)+PRCPVL
      PDACCT(NM,3) = PDACCT(NM,3)+STRVOL
      PDACCT(NM,4) = PDACCT(NM,4)+SEVAP/3630.0
      PDACCT(NM,5) = PDACCT(NM,5)+DASEEP
      PDACCT(NM,6) = PDACCT(NM,6)+DSCHRG
      PDACCT(NM,7) = PDACCT(NM,7)+(PONVOL-PDVOL)
      IF (ND.EQ.NDAYS) PDACCT(NM,8) = H
       PDVOL = PONVOL
      IF (PONVOL.GT.MAXVOL) MAXVOL = PONVOL
      IF (ND.EQ.NDAYS) PDACCT(NM,9) = PONVOL/VOLMAX*100.
	AVGPNDFULL = AVGPNDFULL+PDACCT(NM,9)
!     *****
!                ******************************************************************
!     *****
!     *****  PRINT DAILY INFORMATION FOR LAST YEAR OF SIMULATION TO A FILE.
!     *****  DVAL IS AN ARRAY TO STORE DAILY VALUES FOR PRINTING.
!     *****
      IF (NY.NE.YEARS) GO TO 649 
      DO 635 LL=1,NPLOTS
      DVAL(LL,1)=TIRRG(LL)
      DVAL(LL,2)=NIA(LL)
      DVAL(LL,3)=NRNOF(LL)
      DVAL(LL,4)=NDPERC(LL)
      DVAL(LL,5)=AETU(LL)+AETL(LL)
      DVAL(LL,6)=SM(LL)
  635 CONTINUE 
      NTMX=TMAX(ND)
      NTMN=TMIN(ND)
      WRITE (16,640) NM,ND,NTMX,NTMN,PRECIP,PETX,&
       ((DVAL(L6,L5),L5=1,6),L6=1,NPLOTS)
  640 FORMAT (I2,I3,2I4,2F5.2,24(5F5.2,F6.2))     
!     *****   STATISTICAL PRECIPITATION AND RUNOFF FREQUENCY CALCULATIONS
  649 IF (PREC(ND).GT.0.0) CTPDAY = CTPDAY+1.0
      IPLOT = NPLOTS
      IF (NPLOTS.GT.4) NPLOTS = 4
      DO 660 II=1,25
      IF (PREC(ND).GT.FREQ(II)) CTP(II) = CTP(II)+1.0
      CNTR = 0.0
      DO 650 KI=1,NPLOTS
      IF (NRNOF(KI).GT.0.0.AND.II.EQ.1) CTRDAY(KI) = CTRDAY(KI)+1.0
      IF (NRNOF(KI).GT.0.0) CNTR = 1.0
  650 IF (NRNOF(KI).GT.FREQ(II)) CTR(II,KI) = CTR(II,KI)+1.0
  660 IF (PREC(ND).GT.FREQ(II).AND.CNTR.EQ.1.0) CTPR(II) = CTPR(II)+1.0
      NPLOTS = IPLOT
  670 CONTINUE
!     *****
!     *****   ***** EXIT DAILY LOOP *****
!     *****
!     *****   UPDATE ACCOUNTS
      PETACT(13)=PETACT(13)+PETACT(NM)
      PDACCT(NM,1) = MONTHT(NM)
      DO 680 J=2,7
      PDACCT(13,J) = PDACCT(13,J)+PDACCT(NM,J)
  680 CONTINUE
      DO 700 MP=1,NPLOTS
      SMACCT(NM,8,MP) = SM(MP)
      DO 690 J=2,9
  690 SMACCT(13,J,MP) = SMACCT(13,J,MP)+SMACCT(NM,J,MP)
      SMACCT(NM,1,MP) = MONTHT(NM)
  700 CONTINUE
  710 CONTINUE
!     *****
!     *****   ***** EXIT MONTHLY LOOP *****
!     *****
      PDACCT(13,1) = MONTHT(13)
      DO 720 MP=1,NPLOTS
      SMACCT(13,1,MP) = MONTHT(13)
      SMACCT(13,8,MP) = SMACCT(12,8,MP)
  720 CONTINUE
!     *****   DSNOW=CHANGE IN SNOWPACK STORAGE (IN.)
!     *****   PACKPY=SNOWPACK STORAGE FOR NEXT YEAR'S CALCULATIONS (IN)
!     *****   DSRNFF=ANNUAL PRECIPITATION EXCESS FROM EACH HRU (IN.)
!     *****   AINTER=ANNUAL INTERCEPTION AMOUNT FOR EACH HRU (IN.)
!     *****   AAETRS=ANNUAL ACTUAL ET FROM EACH HRU (IN.)
!     *****   ACHSOM=ANNUAL CHANGE IN SOIL MOISTURE FOR EACH HRU (IN.)
!     *****   DSPERC=ANNUAL DEEP PERCOLATION AMOUNT FOR EACH HRU (IN.)
!     *****   PEACCT=ANNUAL PRECIPITATION EXCESS FROM EACH HRU (IN.)
!     *****   TPREC=TOTAL PRECIPITATION FOR SIMULATION RUN (IN.)
!     *****   DRY=LOWEST ANNUAL PRECIPITATION AMOUNT (IN.)
!     *****   WET=GREATEST ANNUAL PRECIPITATION AMOUNT (IN.)
!     *****   NYDSCH=TOTAL NUMBER OF YEARS HAVING A DISCHARGE
!     *****   PRCPT=TOTAL VOLUME OF DIRECT PRECIPITATION ON THE
!     *****   RESERVIOR SURFACE DURING THE SIMULATION RUN (ACRE-INCHES)
!     *****   PEINT=TOTAL VOLUME OF PRECIPITATION EXCESS FLOWING INTO
!     *****   RESERVOIR DURING THE SIMULATION RUN (ACRE-INCHES)
!     *****   EVAPT=TOTAL VOLUME OF EVAPORATION FROM THE RESERVOIR SURFACE
!     *****   DURING THE SIMULATION RUN (ACRE-INCHES)
!     *****   EXFILT=TOTAL VOLUME OF GROSS SEEPAGE FROM THE RESERVOIR
!     *****   DURING THE SIMULATION RUN (ACRE-INCHES)
!     *****   MAXVOL=MAXIMUM % OF RESERVOIR VOLUME UTILIZED DURING THE SIMULATION RUN
!     *****   EVAPLK=TOTAL CALCULATED LAKE EVAPORATION FOR SIMULATION RUN (INCHES)
!     *****   DAYLD=VOLUME OF PRECIPITATION EXCESS FROM THE RESERVOIR WATERSHED (INCHES)
      PETTAC=PETTAC+PETACT(13)
      PDACCT(13,8) = PDACCT(12,8)
      DSNOW = PACK(1)-PACKPY
      PACKPY = PACK(1)
      DO 730 KT=1,NPLOTS
      DSRNFF(KT) = DSRNFF(KT)+SMACCT(13,4,KT)
      AINTER(KT) = AINTER(KT)+SMACCT(13,3,KT)
      AAETRS(KT) = AAETRS(KT)+SMACCT(13,6,KT)
      ACHSOM(KT) = ACHSOM(KT)+SMACCT(13,7,KT)
      DSPERC(KT) = DSPERC(KT)+SMACCT(13,5,KT)
      PEACCT(KT) = SMACCT(13,4,KT)
      AIRRIG(KT) = AIRRIG(KT)+SMACCT(13,9,KT)
  730 CONTINUE
      TPREC = TPREC+SMACCT(13,2,1)
      IF (YEAR.EQ.YSTART) DRY = SMACCT(13,2,1)
      IF (SMACCT(13,2,1).GE.WET) WET = SMACCT(13,2,1)
      IF (SMACCT(13,2,1).LE.DRY) DRY = SMACCT(13,2,1)
      IF (PDACCT(13,6).GT.0.0) NYDSCH = NYDSCH+1
      PRCPT = PRCPT+PDACCT(13,2)
      PEINT = PEINT+PDACCT(13,3)
      EVAPT = EVAPT+PDACCT(13,4)
      EXFILT = EXFILT+PDACCT(13,5)
      MAXVOL = MAXVOL*100.0/VOLMAX
      EVAPLK = EVAPLK+LKEVPT
      DAYLD = PDACCT(13,6)/DA
      DAYPE = (PDACCT(13,4)-PDACCT(13,2))/DA
      PDSEEP =PDACCT(13,5)/DA 
!     *****
!     *****                         PRINT RESERVOIR ACCOUNT
!     *****
      GOTO (740,770,740,770,740,770) OUTPUT
!     *****
!     *****             PRINT RESERVOIR ACCOUNT ANNUAL VALUES ONLY
!     *****
  740 WRITE (5,750) YEAR
  750 FORMAT (/,15X,'WATER ACCOUNT FOR THE RESERVOIR IN ACRE-INCHES FOR ',&
     &I4,/,79('-'),/,7X,'INFLOWS',25X,'OUTFLOWS',/,22('-'),2X,38('-'),1X&
     &,'DELTA   ENDING',/,'PRECIP. PRECIP. EXCESS  SURFACE EVAP.   SEEPA&
     &GE     DISCHARGE  VOLUME  DEPTH,FT')
      WRITE (5,760) (PDACCT(13,K),K=2,8)
      WRITE (30,761) PINDX,ISOIL(1),DA/640.,YEAR,&
         (PDACCT(13,K)/(12.*DA/640.),K=2,5),&
	 PDACCT(13,5)*0.9/(12.*DA/640.),&
	 PDACCT(13,6)/(12.*DA/640.),AVGPNDFULL/12.
     LAVGPNDFULL=LAVGPNDFULL+AVGPNDFULL/12.
! writes to simple ASCII file for annual reservoir balance output      
! STATIONID, SOIL(1), DRAINAGE AREA, Year, PRECIP ON POND, INFLOW,
!POND EVAP, GROSS SEEPAGE, NET SEEPAGE, OVERFLOW, AVG % FULL
! all quantities are in acre-feet/sq mile of TYPICAL pond drainage area except AVG % FULL      
  760 FORMAT (F6.1,F11.1,F15.1,F13.1,F14.1,F9.1,F9.2)
  761 FORMAT (I6,I3,F6.3,I5,6F8.3,F5.1)
      GOTO 800
!     *****
!     *****             PRINT RESERVOIR ACCOUNT ON MONTHLY BASIS
!     *****
  770 WRITE (5,780) YEAR
  780 FORMAT (/,15X,'WATER ACCOUNT FOR THE RESERVOIR IN ACRE-INCHES FOR ',&
     &I4,/,79('-'),/,13X,'INFLOWS',21X,'OUTFLOWS',/,6X,22('-'),2X,31('-'&
     &),'  DELTA   ENDING'/,'MONTH PRECIP. PRECIP. EXCESS  SURFACE EVAP.&
     & SEEPAGE DISCHARGE  VOLUME  DEPTH,FT')
      WRITE (5,790) ((PDACCT(I,K),K=1,8),I=1,13)
  790 FORMAT (F4.0,F6.1,F13.1,F14.1,F12.1,F9.1,F10.1,F9.2)
  800 WRITE (5,810) PACK(1),YEAR,DSNOW
  810 FORMAT (/,'HRU NO. 1 SNOW PACK MOISTURE STORAGE INFORMATION&
          & INCHES):',/,'  MOISTURE STORED IN SNOW PACK ON DEC. 31---',F5.2,/,&
     &'  CHANGE IN STORAGE DURING ',I4,' =',F5.2//,'  CHANGE IN SOIL MOI&
     &STURE = (INPUTS) - (OUTPUTS) +/- (CHANGE IN SNOW STORAGE)')
      DO 920 N3=1,NPLOTS
      GOTO (840,870,840,870,840,870) OUTPUT
!     *****
!     *****      PRINT SOIL MOISTURE ACCOUNT ANNUAL TOTALS ONLY
!     *****
  840 WRITE (5,850) N3,YEAR,KROP(PCROP(N3))
  850 FORMAT (/,'HRU NO.',I3,'  WATER BALANCE (INCHES) FOR HRU&
     & FOR ',I4,2X,'LAND USE = ',A24,/,79('-'),/,3X,'INPUTS',23X,'OUTPUTS',20X,'SOIL MOISTURE&
     &',/,13('-'),4X,39('-'),2X,15('-'),/,'PRECIP. IRRIG.    INTRCPTN PR&
     &ECIP.EXCESS  PERC.   AET       CHANGE  TOTAL')
      WRITE (5,860) SMACCT(13,2,N3),SMACCT(13,9,N3),(SMACCT(13,N2,N3),N2& 
       =3,8)
  860 FORMAT (F6.2,F7.2,F11.2,F12.2,F9.2,F8.2,F10.2,F9.2,F8.2)
!      IF (CROP.NE.JCROP) GOTO 920
!      IF (SKPLOT.EQ.N3) GOTO 920
!      WRITE (5,865) SMDI,SPER,AMONTH(MBEGIN),AMONTH(MEND)
!  865 FORMAT (4X,'SOIL MOISTURE DROUGHT INDEX = ',I4,' DAYS, WITH ',
!     1I4,' CONSECUTIVE DAYS'/5X,'WITH LESS THAN ADEQUATE SOIL MOISTURE
!     2 DURING ',A4,' THROUGH ',A4)
!      WRITE (5,866) VOLPER,AMONTH(MPOND)
!  866 FORMAT ('RESERVOIR WAS ',F6.2,'% FULL AT BEGINNING OF 'A4)
      GOTO 920
!     *****
!     *****       PRINT SOIL MOISTURE ACCOUNTS ON MONTHLY BASIS
!     *****
  870 WRITE (5,880) N3,YEAR,KROP(PCROP(N3))
  880 FORMAT (/,'HRU NO.',I3,'  WATER BALANCE (INCHES) FOR HRU &
     &FOR ',I4,2X,'LAND USE = ',A24,/,79('-')/,10X,'INPUTS',19X,'OUTPUTS',20X,'SOIL MOISTUR&
     &E',/,6X,14('-'),2X,36('-'),3X,15('-'),/,'MONTH PRECIP. IRRIG.  INT&
     &RCPTN PRECIP.EXCESS  PERC.  AET       CHANGE  TOTAL')
      DO 900 N1=1,13
      WRITE (5,890) (SMACCT(N1,N2,N3),N2=1,2),SMACCT(N1,9,N3),(SMACCT(N1&
      ,N2,N3),N2=3,8)
  890 FORMAT (F5.0,F7.2,F8.2,F9.2,F11.2,F10.2,F7.2,F11.2,F8.2)
  900 CONTINUE
  920 CONTINUE
      AVGPNDFULL=AVGPNDFULL/12.
      GOTO (930,941,930,941,930,941) OUTPUT
!     *****************************************************************
!     *****
!     *****  This section revised November 26, 1990 to include precip.,
!     *****  lake evap.M reservior excess, and the set of annual values,
!     *****  and to report in actual depths.
!     *****  Further revised September 03, 1993 to include NET reservoir evap.
!     *****  (Evaporation from reservoir- precipitation onto reservoir surface)
!     *****  in depth over its drainage area.
!     *****
!     *****   PRINT DATA FILE stationannlsurf.out FOR ANNUAL VALUES 
!     *****    as follows:
!     *****
!     *****  YEAR, PRECIP, LAKE EVAP, NET RESERVOIR EVAP, RESERVOIR OVERFLOW,AVERAGE END-OF-MONTH % FULL FOR THE YEAR
!     *****  FOLLOWED BY PRECIP EXCESS FOR EACH HRU 1 to N.  HEADINGS FOR THE OUTPUT ARE AS FOLLOWS:
!     *****  YEAR PRECP LKEVP NETEVP OVRFL %FUL  RUNOFF FROM ALL HRUS WITH UNITS OF INCHES EXCEPT FOR % FULL
!     *****  AND NETEVP & OVRFL ARE IN INCHES OF DEPTH OVER THE DRAINAGE AGEA OF THE RESERVOIR
!     *****
!     *****************************************************************
  930 WRITE (4,931) YEAR,SMACCT(13,2,1),LKEVPT,DAYPE,DAYLD,&
      AVGPNDFULL,(PEACCT(I),I=1,NPLOTS)
  931 FORMAT (I4,4F6.2,F6.1,24F6.2)
      GOTO 946
!     *****
!     ******************************************************************
!     *****  Added November 30, 1989 to print monthly values to disk.
!     *****  Revised September 03, 1993 to add NET reservoir evaporation.
!     *****  TOTLKE(I)=Total lake evaporation for month (I)
!     *****  (Evaporation from reservoir- precipitation onto reservoir surface)
!     *****  PDOUTF=Reservoir outflow in inches over its drainage area
!     *****  PDOUTE=NET Reservoir evaporation in inches over its drainage area
!     *****  
!     *****  PRINT DATA FILE stationmnthsurf.out FOR MONTHLY VALUES
!     *****   as follows:
!     *****
!     *****  YR, MO, PRECIP, LAKE EVAP, NET RESERVOIR EVAP, RESERVOIR OUTFLOW, END-OF-MONTH % FULL FOLLOWED BY
!     *****    PRECIP EXCESS FOR EACH HRU 1 to N.  HEADINGS FOR THE OUTPUT ARE AS FOLLOWS:
!     *****  YEAR MO PRECP LKEVP NETEVP OVRFL %FUL  RUNOFF FROM ALL HRUS WITH UNITS OF INCHES EXCEPT FOR % FULL
!     *****  AND NETEVP & OVRFL ARE IN INCHES OF DEPTH OVER THE DRAINAGE AGEA OF THE RESERVOIR
!     *****
!     *****
  941 DO 945 I=1,12
      PDOUTF=PDACCT(I,6)/DA
      PDOUTE=(PDACCT(I,4)-PDACCT(I,2))/DA
      WRITE (6,942) YEAR,I,SMACCT(I,2,1),TOTLKE(I),PDOUTE,PDOUTF,&
      &PDACCT(I,9),(SMACCT(I,4,J),J=1,NPLOTS)
  942 FORMAT (I4,I3,4f7.3,F7.2,25F7.3)
      TOTLKE(I) = 0.0
  945 CONTINUE
  946 GOTO (950,953,950,953,950,953) OUTPUT
!     *****
!     ******************************************************************
!     *****  Added September 03, 1993 to print annual values of perco-
!     *****  lation to disk.  PDSEEP=Reservoir seepage expressed as a depth
!     *****  over its drainage area.  This keeps units consistent with
!     *****  the rest of the water balance accounts.
!     *****
!     *****  PRINT DATA FILE stationannlperc.out FOR ANNUAL VALUES 
!     *****   as follows:
!     *****
!     *****  YR, RESERVOIR SEEPAGE, DEEP PERCOLATION FROM EACH HRU.  OUTPUT FILE CONTENTS ARE AS FOLLOWS:
!     *****  YEAR PONDSEEP IN INCHES OVER THE RESERVOIR DRAINAGE AREA FOLLOWED BY PERCOLATION IN INCHES FROM EACH HRU.
!     *****
!     ******************************************************************
!     *****
  950 WRITE (7,951) YEAR,PDSEEP,(SMACCT(13,5,I),I=1,NPLOTS)
  951 FORMAT (I4,25F6.2)
!     *****
!     ******************************************************************
!     *****
!     *****  ADDED SEPTEMBER 15, 1993 TO PRINT ANNUAL IRRIGATION AMOUNTS
!     *****
!     *****  PRINT AN OUTPUT DATA FILE stationannlirrg.out FOR ANNUAL VALUES 
!     *****   as follows:
!     *****
!     *****  YEAR FOLLOWED BY ANNUAL IRRIGATION DEPTH IN INCHES FOR EACH HRU.
!     *****  
      IF (IPLOT.EQ.0) GOTO 959
      WRITE (10,952) YEAR,(SMACCT(13,9,I),I=1,NPLOTS)
  952 FORMAT (I4,25F6.2)
      GOTO 959
!     *****
!     ******************************************************************
!     *****
!     *****  ADDED SEPTEMBER 15, 1993 TO PRINT MONTHLY IRRIGATION AMOUNTS
!     *****
!     *****  PRINT AN OUTPUT DATA FILE stationmnthirrg.out FOR ANNUAL VALUES 
!     *****   as follows:
!     *****
!     *****  YEAR MO  FOLLOWED BY MONTHLY IRRIGATION DEPTH IN INCHES FOR EACH HRU.
!     *****  
  953 IF (IPLOT.EQ.0) GOTO 956
      DO 955 I=1,12
      WRITE (9,954) YEAR,I,(SMACCT(I,9,J),J=1,NPLOTS)
  954 FORMAT (I4,I3,24F6.2)
  955 CONTINUE
!     *****
!     ******************************************************************
!     *****
!     *****  Added September 03, 1993 to print monthly values of perco-
!     *****  lation to disk.  PONDSP=Reserviur seepage expressed as a depth
!     *****  over its drainage area.  This keeps units consistent with
!     *****  the rest of the water balance accounts.
!     *****
!     *****  PRINT DATA FILE stationmnthperc.out FOR MONTHLY VALUES 
!     *****   as follows:
!     *****
!     *****  YR, MO, RESERVOIR SEEPAGE, DEEP PERCOLATION FROM EACH HRU.  OUTPUT FILE CONTENTS ARE AS FOLLOWS:
!     *****  YEAR MO PNDSEEP IN INCHES OVER THE RESERVOIR DRAINAGE AREA FOLLOWED BY PERCOLATION IN INCHES FROM EACH HRU.
!     *****
  956 DO 958 I=1,12
      PONDSP=PDACCT(I,5)/DA
      WRITE (8,957) YEAR,I,PONDSP,(SMACCT(I,5,J),J=1,NPLOTS)
  957 FORMAT (I4,I3,25F6.3)
  958 CONTINUE
!     *****
  959	LY=LY+1
	IF(LY.GT.6) LY=1
!     ******************************************************************
  960 CONTINUE
!     *****
!      WRITE (*,961)
!  961 FORMAT (//,'      Now preparing final summary and doing post-proce&
!     &ssing, if requested.'//)
!     *****
!     *****   ***** EXIT YEARLY LOOP *****
!     *****
!     *****
!     *****   CALCULATE AVERAGE ANNUAL VALUES
!     *****   RANGE=RANGE OF ANNUAL PRECIPITATION AMOUNTS (IN.)
!     *****   AVGMD=AVERAGE MOISTURE DEFICIT (IN.)
  970 EVAP = EVAPLK/YEARS
      APREC = TPREC/YEARS
      RANGE = WET-DRY
      AVGMD = EVAP-APREC
      PRCPA = PRCPT/YEARS
      PEINA = PEINT/YEARS
      EVAPA = EVAPT/YEARS
      EXFILA = EXFILT/YEARS
      DSCRGA = DSCVOL/YEARS
      PETAVG = PETTAC/YEARS
      LAVGPNDFULL=LAVGPNDFULL/YEARS
      IF (NYDSCH) 990,990,980
!     *****   ADYD=AVG. NUMBER OF DISCHARGES/YEARS HAVING A DISCHARGE
!     *****   AVANDC=AVERAGE ANNUAL DISCHARGE VOLUME
  980 ADYD = NODSCH/NYDSCH
      AVANDC = DSCVOL/NYDSCH
      DSCRG = DSCVOL/NODSCH
      GOTO 1000
  990 ADYD = 0.0
      DSCRG = 0.0
      AVANDC = 0.0
 1000 DO 1010 J=1,NPLOTS
      DSPERC(J) = DSPERC(J)/YEARS
      DSRNFF(J) = DSRNFF(J)/YEARS
      ACHSOM(J) = ACHSOM(J)/YEARS
      AINTER(J) = AINTER(J)/YEARS
      AIRRIG(J) = AIRRIG(J)/YEARS
 1010 AAETRS(J) = AAETRS(J)/YEARS
      IF (NPLOTS.GT.4) NPLOTS = 4
      DO 1030 J=1,25
      PRECAC(J,3) = CTP(J)
      IF (CTPDAY.GT.0.0) CTP(J) = CTP(J)/CTPDAY*100.0
      PRECAC(J,1) = ASTAT(J)
      PRECAC(J,2) = CTP(J)
      PRECAC(J,4) = CTPR(J)
      DO 1020 I=1,NPLOTS
      INUM1 = 5+I
      RUNACC(J,INUM1) = CTR(J,I)
      IF (CTRDAY(I).GT.0.0) CTR(J,I) = CTR(J,I)/CTRDAY(I)*100.0
      INUM = I+1
 1020 RUNACC(J,INUM) = CTR(J,I)
 1030 RUNACC(J,1) = ASTAT(J)
      NPLOTS = IPLOT
!     *****
!     *****   PRINT FINAL SUMMARY
!     *****
      WRITE (5,1040)
 1040 FORMAT (////,26X,'***** FINAL SUMMARY *****',/)
      WRITE (5,1050) LOCATION
 1050 FORMAT ('SUB-BASIN: ',/,A80,/)
      WRITE (5,1060) YSTART,YEND,YEARS
 1060 FORMAT (5X,'PERIOD SIMULATED:  'I4,' TO ',I4,' =',I3,' YEARS',//,&
     &'METEOROLOGICAL SUMMARY',/)
      WRITE (5,1070) EVAP
 1070 FORMAT (5X,'AVERAGE ANNUAL LAKE EVAPORATION=',F6.2,' INCHES')
      WRITE (5,1080) APREC
 1080 FORMAT (5X,'AVERAGE ANNUAL PRECIPITATION=',F6.2,' INCHES')
      WRITE (5,1090) RANGE,DRY,WET
 1090 FORMAT (5X,'PRECIPITATION RANGE=',F6.2,' INCHES',/,8X,'(FROM A LOW&
     & OF',F6.2,' INCHES TO A HIGH OF',F6.2,' INCHES)')
      WRITE (5,1100) AVGMD
 1100 FORMAT (5X,'AVERAGE MOISTURE DEFICIT=',F6.2,' INCHES')
      WRITE (5,1105) PETAVG
 1105 FORMAT (5X,'AVERAGE POTENTIAL EVAPOTRANSPIRATION=',F6.2,' INCHES',&
     &/)
      WRITE (5,1110)
 1110 FORMAT ('SUMMARY OF RESERVOIR OPERATIONS (ALL VOLUMES ARE IN&
     & ACRE-FEET)',/)
      WRITE (5,1120) NYDSCH
 1120 FORMAT (5X,'NUMBER OF YEARS HAVING AN OVERFLOW =',I5)
      WRITE (5,1130) ADYD
 1130 FORMAT (5X,'AVERAGE NUMBER OF OVERFLOWS PER YEAR HAVING AN &
      &OVERFLOW =',F6.2)
      WRITE (5,1140) DSCRG/12.
 1140 FORMAT (5X,'AVERAGE DAILY OVERFLOW VOLUME =',F8.2)
      WRITE (5,1150) PEAK/12.
 1150 FORMAT (5X,'MAXIMUM DAILY OVERFLOW VOLUME =',F8.2)
      WRITE (5,1160) AVANDC/12.
 1160 FORMAT (5X,'AVERAGE OVERFLOW VOLUME PER YEAR HAVING AN &
          &OVERFLOW = ',F9.2)
      WRITE (5,1170) DSCVOL/12.
 1170 FORMAT (5X,'TOTAL OVERFLOW VOLUME=',F10.2)
      WRITE (5,1180) PRCPA/12.
 1180 FORMAT (5X,'AVERAGE ANNUAL DIRECT PRECIPITATION VOLUME=',F8.2)
      WRITE (5,1190) PEINA/12.
 1190 FORMAT (5X,'AVERAGE ANNUAL PRECIPITATION EXCESS VOLUME&
      & FLOWING INTO RESERVOIR=',F9.2)
      WRITE (5,1200) EVAPA/12.
 1200 FORMAT (5X,'AVERAGE ANNUAL EVAPORATION VOLUME=',F8.2)
      WRITE (5,1210) EXFILA/12.
 1210 FORMAT (5X,'AVERAGE ANNUAL SEEPAGE VOLUME=',F8.2)
      WRITE (5,1220) DSCRGA/12.
 1220 FORMAT (5X,'AVERAGE ANNUAL OVERFLOW VOLUME =',F10.2,/)
      WRITE (30,1225) PINDX,ISOIL(1),DA/640.,PRCPA/12.*(640./DA),&
        PEINA/12.*(640./DA),EVAPA/12.*(640./DA),EXFILA/12.*(640./DA),&
	EXFILA/12.*(640./DA)*0.9,DSCRGA/12.*(640./DA),LAVGPNDFULL   
 1225 FORMAT (I6,I3,F6.3,' 9999',6F8.3,F5.1)
      WRITE (5,1240)
 1240 FORMAT ('SUMMARY OF AVERAGE ANNUAL WATER BALANCE FOR EACH&
     & HRU')
      DO 1310 J=1,NPLOTS
      WRITE (5,1250) J
 1250 FORMAT (/,5X,'HRU NO.',I3)
 1255 WRITE (5,1256) AIRRIG(J)
 1256 FORMAT (/,9X,'IRRIGATION ADDED =',F6.2,' INCHES')
      WRITE (5,1260) DSRNFF(J)
 1260 FORMAT (9X,'PRECIPITATION EXCESS =',F6.2,' INCHES')
      WRITE (5,1270) DSPERC(J)
 1270 FORMAT (9X,'PERCOLATION =',F5.2,' INCHES')
      WRITE (5,1280) AINTER(J)
 1280 FORMAT (9X,'INTERCEPTION =',F5.2,' INCHES')
      WRITE (5,1290) AAETRS(J)
 1290 FORMAT (9X,'EVAPOTRANSPIRATION = ',F5.2,' INCHES')
      WRITE (5,1300) ACHSOM(J)
 1300 FORMAT (9X,'CHANGE IN SOIL MOISTURE =',F5.2,' INCHES')
 1310 CONTINUE
!     *****
!  Write long-term average out put to output file, StationID, precip, refETo, and ET, Runoff, and Percolation for unterraced conditions
      WRITE (19,4000,ADVANCE='NO') FILE19,APREC,PETAVG
      WRITE (21,4000,ADVANCE='NO') FILE19,APREC,PETAVG
 4000 FORMAT (A10,2F6.2)
      DO 4200 J=1,2
      WRITE (19,4010,ADVANCE='NO') (AAETRS(J)+AINTER(J))*53.333,&
        DSRNFF(J)*53.333,DSPERC(J)*53.333
      WRITE (21,4010,ADVANCE='NO') (AAETRS(J)+AINTER(J))*53.333,&
        DSRNFF(J)*53.333,DSPERC(J)*53.333	
 4010 FORMAT (F8.2,2F7.2)     
 4200 CONTINUE 
      AVGAAETRS=0.0
      AVGDSRNFF=0.0
      AVGDSPERC=0.0
      DO 4201 J=3,5
      AVGAAETRS=AVGAAETRS+(AAETRS(J)+AINTER(J))*53.333/3.
      AVGDSRNFF=AVGDSRNFF+DSRNFF(J)*53.333/3.
      AVGDSPERC=AVGDSPERC+DSPERC(J)*53.333/3.
 4201 CONTINUE     
      WRITE (19,4010,ADVANCE='NO') AVGAAETRS,AVGDSRNFF,AVGDSPERC
      WRITE (21,4010,ADVANCE='NO') AVGAAETRS,AVGDSRNFF,AVGDSPERC
      AVGAAETRS=0.0
      AVGDSRNFF=0.0
      AVGDSPERC=0.0
      DO 4202 J=6,7
      AVGAAETRS=AVGAAETRS+(AAETRS(J)+AINTER(J))*53.333/2.
      AVGDSRNFF=AVGDSRNFF+DSRNFF(J)*53.333/2.
      AVGDSPERC=AVGDSPERC+DSPERC(J)*53.333/2.
 4202 CONTINUE     
      WRITE (19,4010,ADVANCE='NO') AVGAAETRS,AVGDSRNFF,AVGDSPERC
      WRITE (21,4010,ADVANCE='NO') AVGAAETRS,AVGDSRNFF,AVGDSPERC
      DO 4203 J=8,10
      WRITE (19,4010,ADVANCE='NO') (AAETRS(J)+AINTER(J))*53.333,&
        DSRNFF(J)*53.333,DSPERC(J)*53.333
      WRITE (21,4010,ADVANCE='NO') (AAETRS(J)+AINTER(J))*53.333,&
        DSRNFF(J)*53.333,DSPERC(J)*53.333
 4203 CONTINUE 
 !  Balance pond operations to adjust for slight difference for pond surface area changes by adding difference to discharge
      DAO=640./DA
      PEINAO=PEINA/12.*DAO
      EXFILAO=EXFILA/12.*DAO*0.90
      NETO=(-PRCPA+EVAPA+0.1*EXFILA)/12.*DAO
      DSCRGAO=PEINAO-NETO-EXFILAO
  !  Write long-term average reservoir operations for the run.
      WRITE (19,4210) DAO,PEINAO,DSCRGAO,EXFILAO,NETO,&
      TERRACEDAREA/(DA/640.),LAVGPNDFULL
      WRITE (21,4210) DAO,PEINAO,DSCRGAO,EXFILAO,NETO,&
      TERRACEDAREA/(DA/640.),LAVGPNDFULL       
!      DA/640.,PEINA/12.*(640./DA),&
!      DSCRGA/12.*(640./DA),EXFILA/12.*(640./DA)*0.9,&
!      ((-PRCPA+EVAPA+0.1*EXFILA)/12.*(640./DA)),&
      
 4210 FORMAT (F6.3,4F8.3,F6.3,F5.1)
 !     *****
!     ***** PRINT STATISTICAL SUMMARY
!     *****
      WRITE (5,1320)
 1320 FORMAT (//,'SUMMARY OF STATISTICAL DATA',/)
      WRITE (5,1330)
 1330 FORMAT ('PRECIPITATION FREQUENCY DATA',//,'INTENSITY',5X,&
     &'FREQUENCY',6X,'FREQUENCY',4X,'RUNOFF FREQ.',/2X,'(> IN.)',6X,'( %&
     &)',9X,'(DAYS)',9X,'(DAYS)',/)
      WRITE (5,1340) ((PRECAC(I,J),J=1,4),I=1,25)
 1340 FORMAT (2x,f4.1,3F15.2)
      WRITE (5,1350)
 1350 FORMAT (//,'RUNOFF FREQUENCY DATA',//,'INTENSITY',8X,&
     &'FREQUENCY ( % )',20X,'FREQUENCY (DAYS)',/,'  (> IN.)',2X,'HRU 1&
     &   HRU 2   HRU 3   HRU 4',5X,'  HRU 1   HRU 2   HRU 3   HRU 4',/)
      WRITE (5,1360) ((RUNACC(I,J),J=1,9),I=1,25)
 1360 FORMAT (2X,f4.1,2X,4F8.2,4X,4F8.2)
      DO 1370 I=3,10      
      CLOSE (I,STATUS='KEEP')
 1370 CONTINUE
 2900 CLOSE (12,STATUS='DELETE')
      DO 2920 JJ=31,40 
      Write(JJ,*) '999,0,0,0,0,0,0,0,0,0,0'
      CLOSE (JJ,STATUS='KEEP')
 2920 CONTINUE     
 3000 STOP
      END PROGRAM POTYLDR2
!     *****
!     ******************************************************************
      SUBROUTINE INTERCEPTION (JJ,INTERC,IACCT,KROPKO,RAIN,PETD,PET,TAVG,&
             MUL,SNOWPACK,SNOVAP,CONSTANT)
!     *****   SUBROUTINE INTERCEPTION CALCULATES:
!     *****     1. THE AMOUNT OF PRECIPITATION + IRRIGATION WHICH IS INTERCEPTED FOR THE DAY, INTERC
!     *****     2. THE VALUE OF INTERCEPTION STORAGE FOR THE NEXT DAY'S SIMULATION, IACCT
!     *****     3. THE SIZE OF THE INTERCEPTION ACCOUNT, INPOT =CONSTANT*(MUL*KROPKO) TO ESTIMATE THE 
!     *****         AMOUNT OF WATER THAT DOES NOT MAKE IT TO THE SOIL MOISTURE ACCOUNT
!     *****        IAET=AMOUNT OF EVAPOTRANSPIRATION WHICH IS DEDUCTED FROM INTERCEPTION STORAGE (INCHES)
!     *****     4. SNOVAP CONSIDERED PART OF INTERCEPTION PROCESS AND IT EVALUATED AS PART OF THE INTERCEPTION ROUTINE.
      REAL INTERC,IAET,INPOT,KROPKO,MUL,IACCT
      INTERC=0.0
      SNOVAP=0.0
      PET=PETD
      IAET=0.0
      INPOT=0.0
      IF(SNOWPACK.EQ.0.) GOTO 20
          SNOVAP=0.5*PETD*(1-MUL)
      IF(SNOVAP.GT.SNOWPACK) THEN
	     SNOVAP=SNOWPACK
             SNOWPACK=0.0
	     INTERC=SNOVAP
	     PET=PETD-SNOVAP
      ELSE 
        SNOWPACK=SNOWPACK-SNOVAP
        INTERC=SNOVAP
        PET=PETD-SNOVAP
       ENDIF
       GOTO 50
   20  IF(TAVG.GT.32.) GOTO 30
       GOTO 50
   30 INPOT = CONSTANT*(KROPKO+MUL)
       IF(INPOT.GT.0.10) INPOT=0.10 !SETS INTERCEPTION POTENTIAL TO MAX OF 0.10 INCHES
       IF(IACCT.GT.INPOT) INPOT=IACCT  !INPOT CHANGES BASED ON CONDITIONS WITH KROPKO +MUL.  IF IT DROPS BELOW THE 
       IF((RAIN+IACCT).GT.INPOT) THEN  !AMOUNT THE CARRY OVER IN THE INTERCEPTION ACCOUNT, THAT EXTRA WATER IS NOT LOST.
           INTERC=INPOT-IACCT
	   IACCT=INPOT
       ELSE
        INTERC = RAIN
        IACCT=IACCT+RAIN
       ENDIF
      IAET=PETD-IACCT  !CHECK TO SEE IF THERE IS ENOUGH PETD TO EMPTY THE INTERCEPTION ACCOUNT
      IF(IAET.LT.0.) THEN ! NOT ENOUGH PETD TO EMPTY THE INTERCEPTION ACCOUNT
        IAET=PETD
	IACCT=IACCT-IAET
	PET=0.0
      ELSE  ! PETD IS GREATER THAN THE AMOUNT IN THE INTERCEPTION ACCCOUNT, SO 
      PET=PETD-IACCT
      IACCT=0.0   
      ENDIF
   50 RETURN
      END
!     *****
!     *****      
      SUBROUTINE RNOFRT (ZAVFCU,ZPWPUZ,RAIN,RCN2,RNOF,ZSMUZ)
!     *****
!     *****   SUBROUTINE RNOFRT CALCULATES THE RUNOFF FROM THE HRU
!     *****   USING THE SCS EQUATION:
!     *****        RNOF=((P-0.2*S)**2)/(P+0.8*S)
!     *****   WHERE
!     *****        P (RAIN)=PRECIPITATION AMOUNT, INCLUDING SNOWMELT (INCHES)
!     *****        S=(1000/CN)-10
!     *****        CN=RUNOFF CURVE NUMBER
!     *****        RNOF=CALCULATED RUNOFF AMOUNT (INCHES)
      REAL NUM
!     *****
!     *****************************************************************
!     *****
!     *****  RCN CHANGED TO SLIDING SCALE BASED UPON AVAILABLE SOIL
!     *****  IN UPPER ZONE OF SOIL (FASMUZ) BY SIMPLE FITTED EQUATION.
!     *****  CHANGED SEPTEMBER 07 and 20, 1993 JKK
!     *****  DIFFERENT THRESHOLD VALUES FOR GROWING AND NON-GROWING
!     *****  SEASONS WERE ELIMINATED BECAUSE FASMUZ SHOULD ACCOUNT FOR
!     *****  CHANGES BECAUSE SOIL MOISTURE IS LIKELY HIGHER DURING THE 
!     *****  NON-GROWING SEASON.
!     *****  IF FASMUZ.LT.65%, AMCI; IF .GT.95%, AMCIII, IN BETWEEN
!     *****  SLIDES FROM I TO III WITH AMCII AT 75%.
!     *****  TCNF = RUNOFF CURVE NUMBER REDUCTION FACTOR FOR TERRACED HRUs OR 
!     *****  TO ADJUST RCN FOR OTHER PURPOSES SUCH AS RESIDENTIAL OR DIFFERENT MANAGEMENT
!     *****************************************************************
!     *****
      RCN3= -0.0056*RCN2**2+1.4472*RCN2+10.97
      RCN1= 0.0095*RCN2**2-0.1739*RCN2+15.985
      FASMUZ=(ZSMUZ-ZPWPUZ)/ZAVFCU
      IF (FASMUZ.LT.0.65) GOTO 40
      IF (FASMUZ.GT.0.95) GOTO 50
      AMC=1.00+6.666*(FASMUZ-0.65)
      IF (AMC.LT.2.00) CN=RCN2+(RCN2-RCN1)*(AMC-2.00)
        IF (CN.LT.RCN1) CN=RCN1
      IF (AMC.GE.2.00) CN=RCN2+(RCN3-RCN2)*(AMC-2.00)
        IF (CN.GT.RCN3) CN=RCN3
      GOTO 60    
   40 CN = RCN1
      GOTO 60
   50 CN =RCN3
   60 S = 1000.0/CN-10.0
      NUM = RAIN-0.2*S
      IF (NUM) 70,70,80
   70 RNOF = 0.0
      GOTO 90
   80 RNOF = NUM**2/(RAIN+0.8*S)
   90 RETURN
      END
!     ****      
      SUBROUTINE SNOWMELT (PRECIP,MELT,SNOWPACK,TAVG)
!     ****
!     ****   SUBROUTINE SNOWMELT CALCULATES THE WATER ADDED TO THE PRECIP FOR THE DAY ON HRU DUE TO MELTING OF THE SNOWPACK
!     ****   IT IS CALLED ONLY WHEN THE SNOWPACK IS GREATER THAN ZERO AND TAVG IS GREATER THAN 32 DEGREES.
      REAL MA,MR
      MELT = 0.0
!     ****   MA=SNOWMELT DUE TO ATMOSPHERIC CONDITIONS (INCHES)
   40 MA = 0.05*(TAVG-34.)
      IF (MA.LT.0.0) MA = 0.0
      IF (SNOWPACK-MA) 60,60,50
!     *****   MR=SNOWMELT DUE TO RAIN (INCHES)
   50 MR = (PRECIP*(TAVG-32.))/144.
!     *****   M=TOTAL SNOWMELT (INCHES)
      MELT = MR+MA
      IF (SNOWPACK-MELT) 60,70,70
   60 MELT = SNOWPACK
      SNOWPACK = 0.0
      GOTO 90
   70 SNOWPACK = SNOWPACK-MELT
   90 RETURN
      END
!     *****
      SUBROUTINE VOLRT (AL,W,S,H,HMAX,DSEPRT,A1,A2,A3,A4,A5,PSAREA,VOLMAX)
!     *****
!     *****   SIZING RESERVOIR VOLUME ROUTINE
      A1=AL*W

      A2 = S*(AL+W)
      A3 = 4./3.*S**2
      A4 = 2.*A2
      A5 = 4.*S**2
!     *****   VOLMAX=MAXIMUM STORAGE VOLUME IN THE RESERVOIR (ACRE-IN.)
      VOLMAX = (A1*HMAX+ A2*HMAX**2 +A3*HMAX**3)/3630.0
!     *****   PSAREA=MAXIMUM RESERVOIR SURFACE AREA (ACRES)
      PSAREA = ((W+2.*S*HMAX)*(AL+2.*S*HMAX))/43560.0
      RETURN
      RETURN
	  END
	